@@ -325,7 +325,7 @@ if(pri)
 			}
 			else if(pri->primval.number->numtype==NV_RVAL)
 			{
-			printf("PRIM: %lf\n",pri->primval.number->num.rval);
+			printf("PRIM: %.16g\n",pri->primval.number->num.rval);
 			}
 			else
 			{
@@ -372,8 +372,11 @@ printf("CONCAT ^^^ ---------------------------------------------\n");
 }
 
 /*
- * $Id: inter.c,v 1.1.1.1 2007/05/30 04:25:42 gtkwave Exp $
+ * $Id: inter.c,v 1.2 2009/12/25 01:55:44 gtkwave Exp $
  * $Log: inter.c,v $
+ * Revision 1.2  2009/12/25 01:55:44  gtkwave
+ * warnings fixes
+ *
  * Revision 1.1.1.1  2007/05/30 04:25:42  gtkwave
  * Imported sources
  *
