@@ -831,24 +831,50 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 				}
 				else
 				{
-				int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
-				if(rows)
+				ulong sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+				if(sf)
 					{
-		                        for(r=1;r<rows+1;r++)
-		                                {
-						nptr np; 
-		                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc, r);
-
-		                                GLOBALS->ae2_fr[i].row = row;
-
-						np = GLOBALS->ae2_lx2_table[i][row].np;
-		                                ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
-						if(strcmp(np->mv.value, buf))
-							{
-							strcpy(np->mv.value, buf);
-							ae2_callback(&cyc, &i, &np->mv.value, row);
-							}
-		                                }
+					int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
+					if(rows)
+						{
+			                        for(r=1;r<rows+1;r++)
+			                                {
+							nptr np; 
+			                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc, r);
+	
+			                                GLOBALS->ae2_fr[i].row = row;
+	
+							np = GLOBALS->ae2_lx2_table[i][row].np;
+			                                ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
+							if(strcmp(np->mv.value, buf))
+								{
+								strcpy(np->mv.value, buf);
+								ae2_callback(&cyc, &i, &np->mv.value, row);
+								}
+			                                }
+						}
+					}
+					else
+					{
+					int rows = ae2_read_symbol_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+					if(rows)
+						{
+			                        for(r=0;r<rows;r++)
+			                                {
+							nptr np; 
+			                                uint64_t row = r;
+	
+			                                GLOBALS->ae2_fr[i].row = row;
+	
+							np = GLOBALS->ae2_lx2_table[i][row].np;
+			                                ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
+							if(strcmp(np->mv.value, buf))
+								{
+								strcpy(np->mv.value, buf);
+								ae2_callback(&cyc, &i, &np->mv.value, row);
+								}
+			                                }
+						}
 					}
 				}
 			}
@@ -872,28 +898,58 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 			}
 			else
 			{
-			int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
-			uint64_t mxcyc = end_cycle+1;
-
-                        for(r=1;r<rows+1;r++)
-                                {
-				/* nptr np; */
-                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc, r);
-
-                                GLOBALS->ae2_fr[i].row = row;
-				/* np = GLOBALS->ae2_lx2_table[i][row].np; */
-				ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
-
-				if((ncyc > cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
-				}
-
-			if(mxcyc != (end_cycle+1))
+			ulong sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+			if(sf)
 				{
-				ncyc = mxcyc;
+				int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc);
+				uint64_t mxcyc = end_cycle+1;
+
+	                        for(r=1;r<rows+1;r++)
+	                                {
+					/* nptr np; */
+	                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, cyc, r);
+
+	                                GLOBALS->ae2_fr[i].row = row;
+					/* np = GLOBALS->ae2_lx2_table[i][row].np; */
+					ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
+	
+					if((ncyc > cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
+					}
+
+				if(mxcyc != (end_cycle+1))
+					{
+					ncyc = mxcyc;
+					}
+					else
+					{
+					ncyc = cyc;
+					}
 				}
 				else
 				{
-				ncyc = cyc;
+				int rows = ae2_read_symbol_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+				uint64_t mxcyc = end_cycle+1;
+
+	                        for(r=0;r<rows;r++)
+	                                {
+					/* nptr np; */
+	                                uint64_t row = r;
+
+	                                GLOBALS->ae2_fr[i].row = row;
+					/* np = GLOBALS->ae2_lx2_table[i][row].np; */
+					ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, cyc, buf);
+	
+					if((ncyc > cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
+					}
+
+				if(mxcyc != (end_cycle+1))
+					{
+					ncyc = mxcyc;
+					}
+					else
+					{
+					ncyc = cyc;
+					}
 				}
 			}
 
@@ -942,35 +998,72 @@ for(j=0;j<GLOBALS->ae2_num_sections;j++)
 					}
 					else
 					{
-					int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, step_cyc);
-					uint64_t mxcyc = end_cycle+1;
-
-		                        for(r=1;r<rows+1;r++)
-	        	                        {
-						nptr npr; 
-		                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, step_cyc, r);
-
-		                                GLOBALS->ae2_fr[i].row = row;
-						npr = GLOBALS->ae2_lx2_table[i][row].np;
-
-						ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
-						if(strcmp(buf, npr->mv.value))
-							{
-							strcpy(npr->mv.value, buf);
-							ae2_callback(&step_cyc, &i, &npr->mv.value, row);
-							}
-
-						ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
-						if((ncyc > step_cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
-						}
-
-					if(mxcyc != (end_cycle+1))
+					ulong sf = ae2_read_symbol_sparse_flag(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+					if(sf)
 						{
-						ncyc = mxcyc;
+						int rows = ae2_read_num_sparse_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, step_cyc);
+						uint64_t mxcyc = end_cycle+1;
+
+			                        for(r=1;r<rows+1;r++)
+		        	                        {
+							nptr npr; 
+			                                uint64_t row = ae2_read_ith_sparse_row(GLOBALS->ae2, GLOBALS->ae2_fr[i].s, step_cyc, r);
+
+			                                GLOBALS->ae2_fr[i].row = row;
+							npr = GLOBALS->ae2_lx2_table[i][row].np;
+
+							ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
+							if(strcmp(buf, npr->mv.value))
+								{
+								strcpy(npr->mv.value, buf);
+								ae2_callback(&step_cyc, &i, &npr->mv.value, row);
+								}
+
+							ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
+							if((ncyc > step_cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
+							}
+	
+						if(mxcyc != (end_cycle+1))
+							{
+							ncyc = mxcyc;
+							}
+							else
+							{
+							ncyc = step_cyc;
+							}
 						}
 						else
 						{
-						ncyc = step_cyc;
+						int rows = ae2_read_symbol_rows(GLOBALS->ae2, GLOBALS->ae2_fr[i].s);
+						uint64_t mxcyc = end_cycle+1;
+
+			                        for(r=0;r<rows;r++)
+		        	                        {
+							nptr npr; 
+			                                uint64_t row = r;
+
+			                                GLOBALS->ae2_fr[i].row = row;
+							npr = GLOBALS->ae2_lx2_table[i][row].np;
+
+							ae2_read_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
+							if(strcmp(buf, npr->mv.value))
+								{
+								strcpy(npr->mv.value, buf);
+								ae2_callback(&step_cyc, &i, &npr->mv.value, row);
+								}
+
+							ncyc =	ae2_read_next_value(GLOBALS->ae2, GLOBALS->ae2_fr+i, step_cyc, buf);
+							if((ncyc > step_cyc) && (ncyc < mxcyc)) mxcyc = ncyc;
+							}
+	
+						if(mxcyc != (end_cycle+1))
+							{
+							ncyc = mxcyc;
+							}
+							else
+							{
+							ncyc = step_cyc;
+							}
 						}
 					}
 		
@@ -1062,13 +1155,22 @@ if((1)||(f->row <= 1)) /* sorry, arrays not supported yet in the viewer */
 	}
 	else
 	{
+	if(nr<1) nr=1;
+	if(!GLOBALS->ae2_lx2_table[txidx])
+		{
+	        GLOBALS->ae2_lx2_table[txidx] = calloc_2(nr, sizeof(struct lx2_entry));
+	        for(r=0;r<nr;r++)
+	                {
+	                GLOBALS->ae2_lx2_table[txidx][r].np = &np[r];
+	                }
+		}
+
 	fprintf(stderr, AET2_RDLOAD"Skipping array: %s (%d rows)\n", np->nname, f->row);
 	}
 
 
 for(r = 0; r < nr; r++)
 	{
-
 	histent_tail = htemp = histent_calloc();
 	if(len>1)
 		{
@@ -1131,8 +1233,6 @@ for(r = 0; r < nr; r++)
 	np[r].head.next = htemp;
 	np[r].numhist=GLOBALS->ae2_lx2_table[txidx][r].numtrans +2 /*endcap*/ +1 /*frontcap*/;
 
-	memset(GLOBALS->ae2_lx2_table+txidx, 0, sizeof(struct lx2_entry));	/* zero it out */
-
 	np[r].curr = histent_tail;
 	np[r].mv.mvlfac = NULL;	/* it's imported and cached so we can forget it's an mvlfac now */
 	}
@@ -1280,8 +1380,17 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 /* ...of AET2_IS_PRESENT */
 
 /*
- * $Id: ae2.c,v 1.16 2010/05/27 06:56:39 gtkwave Exp $
+ * $Id: ae2.c,v 1.19 2010/09/16 15:24:25 gtkwave Exp $
  * $Log: ae2.c,v $
+ * Revision 1.19  2010/09/16 15:24:25  gtkwave
+ * non-sparse array fix
+ *
+ * Revision 1.18  2010/09/16 05:05:16  gtkwave
+ * dummy up sparse vs regular array handling
+ *
+ * Revision 1.17  2010/09/16 04:40:25  gtkwave
+ * disable arrays for now to track down sparse vs regular array crashes
+ *
  * Revision 1.16  2010/05/27 06:56:39  gtkwave
  * printf warning fixes
  *
