@@ -37,6 +37,7 @@ void 		import_ae2_trace(nptr np);
 void 		ae2_set_fac_process_mask(nptr np);
 void 		ae2_import_masked(void);
 
+
 #ifndef _MSC_VER
 /*
  * texsim prototypes/libae2rw interfacing...
@@ -74,6 +75,7 @@ unsigned long	ae2_read_num_symbols(AE2_HANDLE handle);
 unsigned long 	ae2_read_symbol_name(AE2_HANDLE handle, unsigned long symbol_idx, char* name);
 unsigned long	ae2_read_symbol_rows(AE2_HANDLE handle, unsigned long symbol_idx);
 unsigned long	ae2_read_symbol_length(AE2_HANDLE handle, unsigned long symbol_idx);
+unsigned long	ae2_read_symbol_sparse_flag(AE2_HANDLE handle, unsigned long symbol_idx);
 unsigned long 	ae2_read_value(AE2_HANDLE handle, FACREF* fr, uint64_t cycle, char* value);
 uint64_t 	ae2_read_next_value(AE2_HANDLE handle, FACREF* fr, uint64_t cycle, char* value);
 void 		ae2_read_end(AE2_HANDLE handle);
@@ -86,8 +88,11 @@ uint64_t 	ae2_read_ith_sparse_row(AE2_HANDLE handle, unsigned long symbol_idx, u
 #endif
 
 /*
- * $Id: ae2.h,v 1.7 2010/04/27 23:10:56 gtkwave Exp $
+ * $Id: ae2.h,v 1.8 2011/01/22 01:29:24 gtkwave Exp $
  * $Log: ae2.h,v $
+ * Revision 1.8  2011/01/22 01:29:24  gtkwave
+ * sourcecode cleanup / warnings fixes
+ *
  * Revision 1.7  2010/04/27 23:10:56  gtkwave
  * made inttype.h inclusion conditional
  *
