@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,6 +18,10 @@
 #include "vlist.h"
 #include "debug.h"
 
+#ifdef AET2_IS_PRESENT
+#define WAVE_ARRAY_SUPPORT
+#endif
+
 typedef struct _SearchProgressData {
     GtkWidget *window;
     GtkWidget *pbar;
@@ -80,6 +84,10 @@ enum AnalyzerBits  { AN_0, AN_X, AN_Z, AN_1, AN_H, AN_U, AN_W, AN_L, AN_DASH, AN
 
 /* ^^^   Bit representation   ^^^ */
 
+#if (SIZEOF_VOID_P == SIZEOF_DOUBLE)
+#define WAVE_HAS_H_DOUBLE
+#endif
+
 
 #ifdef WAVE_USE_STRUCT_PACKING
 #pragma pack(push)
@@ -94,6 +102,9 @@ union
   {
   unsigned char h_val;  /* value: AN_STR[val] or AnalyzerBits which correspond */
   char *h_vector;	/* pointer to a whole vector of h_val type bits */
+#ifdef WAVE_HAS_H_DOUBLE
+  double h_double;
+#endif
   } v;
 
 TimeType time;        /* time of transition */
@@ -106,17 +117,11 @@ unsigned char flags;  /* so far only set on glitch/real condition */
 
 
 enum HistEntFlagBits
-{ HIST_GLITCH_B, HIST_REAL_B, HIST_STRING_B 
-};
+{ HIST_GLITCH_B, HIST_REAL_B, HIST_STRING_B };
 
 #define HIST_GLITCH (1<<HIST_GLITCH_B)
 #define HIST_REAL   (1<<HIST_REAL_B)
-
-#ifndef STRICT_VCD_ONLY
-	#define HIST_STRING (1<<HIST_STRING_B)
-#else
-	#define HIST_STRING 0	/* for gcc -O2 optimization */
-#endif
+#define HIST_STRING (1<<HIST_STRING_B)
 
 #ifdef WAVE_USE_STRUCT_PACKING
 #pragma pack(push)
@@ -177,7 +182,11 @@ struct Node
     int msi, lsi;	/* for 64-bit, more efficient than having as an external struct ExtNode*/
 
     int      numhist;	/* number of elements in the harray */
+
+#ifdef WAVE_ARRAY_SUPPORT
     unsigned int array_height, this_row;
+#endif
+
     unsigned vardir : 2;  /* see nodeVarDir, this is an internal value (currently unused) */
     unsigned vartype : 5; /* see nodeVarType, this is an internal value */
 
@@ -466,7 +475,7 @@ void EnsureGroupsMatch(void);
 #define IsCollapsed(t)  (t->flags&TR_COLLAPSED)
 
 unsigned IsShadowed(Trptr t);
-char*    GetFullName(Trptr t);
+char*    GetFullName(Trptr t, int *was_packed);
 
 void OpenTrace(Trptr t);
 void CloseTrace(Trptr t);
@@ -476,8 +485,14 @@ void ClearGroupTraces(Trptr t);
 #endif
 
 /*
- * $Id: analyzer.h,v 1.35 2010/12/18 23:56:50 gtkwave Exp $
+ * $Id: analyzer.h,v 1.37 2011/01/25 17:43:12 gtkwave Exp $
  * $Log: analyzer.h,v $
+ * Revision 1.37  2011/01/25 17:43:12  gtkwave
+ * cannot remove HIST_STRING for optimization reasons
+ *
+ * Revision 1.36  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
  * Revision 1.35  2010/12/18 23:56:50  gtkwave
  * more structure rearrangement and packing
  *
