@@ -13,6 +13,7 @@
 #define BSEARCH_NODES_VECTORS_H
 
 int bsearch_timechain(TimeType key);
+int bsearch_aetinfo_timechain(TimeType key);
 hptr bsearch_node(nptr n, TimeType key);
 vptr bsearch_vector(bvptr b, TimeType key);
 char *bsearch_trunc(char *ascii, int maxlen);
@@ -21,8 +22,11 @@ struct symbol *bsearch_facs(char *ascii, unsigned int *rows_return);
 #endif
 
 /*
- * $Id: bsearch.h,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
+ * $Id: bsearch.h,v 1.3 2008/02/19 22:56:11 gtkwave Exp $
  * $Log: bsearch.h,v $
+ * Revision 1.3  2008/02/19 22:56:11  gtkwave
+ * rtlbrowse update to handle aet time substitutions
+ *
  * Revision 1.2  2007/08/26 21:35:39  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
