@@ -80,7 +80,7 @@ if(GLOBALS->partial_vcd)
 			{	
 			/* this should never happen! */
 			/* if it does, the program state is probably screwed */
-			printf("GTKWAVE | WARNING: globals changed during gtkwave_main_iteration()!\n");
+			fprintf(stderr, "GTKWAVE | WARNING: globals changed during gtkwave_main_iteration()!\n");
 			gcache = GLOBALS;
 			}
 		}
@@ -161,8 +161,11 @@ if(GLOBALS->busy_busy_c_1)
 }
 
 /*
- * $Id: busy.c,v 1.13 2010/02/18 23:06:04 gtkwave Exp $
+ * $Id: busy.c,v 1.14 2010/08/03 01:33:48 gtkwave Exp $
  * $Log: busy.c,v $
+ * Revision 1.14  2010/08/03 01:33:48  gtkwave
+ * error message to stderr
+ *
  * Revision 1.13  2010/02/18 23:06:04  gtkwave
  * change name of main iteration loop calls
  *
