@@ -200,7 +200,7 @@ for(i=0;i<compar_len;i++)
 	{
 	if((pnt = strchr(s, (int)compar[i])))
 		{
-		if((tolower(pnt[0]) != 'e') && (tolower(pnt[1]) != 'c'))
+		if((tolower((int)(unsigned char)pnt[0]) != 'e') && (tolower((int)(unsigned char)pnt[1]) != 'c'))
 			{
 			return(unformat_time_complex(s, dim));
 			}
@@ -747,8 +747,11 @@ switch(scale)
 }
 
 /*
- * $Id: currenttime.c,v 1.15 2010/01/18 20:47:02 gtkwave Exp $
+ * $Id: currenttime.c,v 1.16 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: currenttime.c,v $
+ * Revision 1.16  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.15  2010/01/18 20:47:02  gtkwave
  * added named locker marking
  *
