@@ -84,12 +84,6 @@
 #define DEBUG(x)
 #endif
 
-#ifdef DEBUG_MALLOC
-#define DEBUG_M(x) x
-#else
-#define DEBUG_M(x)
-#endif
-
 
 #ifdef DEBUG_MALLOC_LINES
 void free_2(void *ptr, char *filename, int lineno);
