@@ -315,7 +315,11 @@ while(s)
 				{
 				if(!(s->his.h->flags&HIST_STRING))
 					{
+#ifdef WAVE_HAS_H_DOUBLE
+					chval=convert_ascii_real(t, &s->his.h->v.h_double);
+#else
 					chval=convert_ascii_real(t, (double *)s->his.h->v.h_vector);
+#endif
 					}
 					else
 					{
