@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2009-2010.
+ * Copyright (c) Tony Bybell 2009-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -353,21 +353,19 @@ for(;;)
 				GLOBALS->extload_idcodes[i] = d2;
 				if(GLOBALS->extload_inv_idcodes[d2] == 0) GLOBALS->extload_inv_idcodes[d2] = i+1; /* root alias */
 
-				GLOBALS->mvlfacs_vzt_c_3[i].array_height=0;
-
 				if(!strcmp("vcd_real", typ))
 					{
 					GLOBALS->mvlfacs_vzt_c_3[i].flags = VZT_RD_SYM_F_DOUBLE;
-					GLOBALS->mvlfacs_vzt_c_3[i].msb=0;				
-					GLOBALS->mvlfacs_vzt_c_3[i].lsb=0;				
+					node_block[i].msi=0;				
+					node_block[i].lsi=0;				
 					GLOBALS->mvlfacs_vzt_c_3[i].len=64;
 					}
 				else
 				if(!strcmp("vcd_integer", typ))
 					{
 					GLOBALS->mvlfacs_vzt_c_3[i].flags = VZT_RD_SYM_F_INTEGER;
-					GLOBALS->mvlfacs_vzt_c_3[i].msb=0;				
-					GLOBALS->mvlfacs_vzt_c_3[i].lsb=0;				
+					node_block[i].msi=0;				
+					node_block[i].lsi=0;				
 					GLOBALS->mvlfacs_vzt_c_3[i].len=32;
 					}
 				else
@@ -378,30 +376,30 @@ for(;;)
 
 					if(esc && lb && rb)
 						{
-						GLOBALS->mvlfacs_vzt_c_3[i].msb = atoi(lb+1);
+						node_block[i].msi = atoi(lb+1);
 						if(colon)
 							{
-							GLOBALS->mvlfacs_vzt_c_3[i].lsb = atoi(colon+1);
+							node_block[i].lsi = atoi(colon+1);
 							}
 							else
 							{
-							GLOBALS->mvlfacs_vzt_c_3[i].lsb = GLOBALS->mvlfacs_vzt_c_3[i].msb;
+							node_block[i].lsi = node_block[i].msi;
 							}						
 
-						len_parse = (GLOBALS->mvlfacs_vzt_c_3[i].msb > GLOBALS->mvlfacs_vzt_c_3[i].lsb)
-								? (GLOBALS->mvlfacs_vzt_c_3[i].msb - GLOBALS->mvlfacs_vzt_c_3[i].lsb + 1)
-								: (GLOBALS->mvlfacs_vzt_c_3[i].lsb - GLOBALS->mvlfacs_vzt_c_3[i].msb + 1);
+						len_parse = (node_block[i].msi > node_block[i].lsi)
+								? (node_block[i].msi - node_block[i].lsi + 1)
+								: (node_block[i].lsi - node_block[i].msi + 1);
 
 						if(len_parse != GLOBALS->mvlfacs_vzt_c_3[i].len)
 							{
-							GLOBALS->mvlfacs_vzt_c_3[i].msb=l;				
-							GLOBALS->mvlfacs_vzt_c_3[i].lsb=r;				
+							node_block[i].msi=l;				
+							node_block[i].lsi=r;				
 							}
 						}
 						else
 						{
-						GLOBALS->mvlfacs_vzt_c_3[i].msb=l;				
-						GLOBALS->mvlfacs_vzt_c_3[i].lsb=r;				
+						node_block[i].msi=l;				
+						node_block[i].lsi=r;				
 						}
 
 					GLOBALS->mvlfacs_vzt_c_3[i].flags = VZT_RD_SYM_F_BITS; 
@@ -442,24 +440,9 @@ if(!GLOBALS->hier_was_explicitly_set)    /* set default hierarchy split char */
 if(GLOBALS->numfacs)
 	{
 	char *fnam = get_varname();
-	char *pnt;
-	int was_packed = 0;
-	
-	if(GLOBALS->do_hier_compress)
-		{
-		pnt = hier_compress(fnam, HIERPACK_ADD, &was_packed);
-		}
-
-	if(was_packed)
-		{
-		namecache[0] = pnt;
-		}
-		else
-		{
-		int flen = strlen(fnam);
-		namecache[0]=malloc_2(flen+1);
-		strcpy(namecache[0], fnam);
-		}
+	int flen = strlen(fnam);
+	namecache[0]=malloc_2(flen+1);
+	strcpy(namecache[0], fnam);
 	}
 
 for(i=0;i<GLOBALS->numfacs;i++)
@@ -471,24 +454,9 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	if(i!=(GLOBALS->numfacs-1))
 		{
 		char *fnam = get_varname();
-		char *pnt;
-		int was_packed = 0;
-
-		if(GLOBALS->do_hier_compress)
-			{
-			pnt = hier_compress(fnam, HIERPACK_ADD, &was_packed);
-			}
-
-		if(was_packed)
-			{
-			namecache[i+1] = pnt;
-			}
-			else
-			{
-			int flen = strlen(fnam);
-			namecache[i+1]=malloc_2(flen+1);
-			strcpy(namecache[i+1], fnam);
-			}
+		int flen = strlen(fnam);
+		namecache[i+1]=malloc_2(flen+1);
+		strcpy(namecache[i+1], fnam);
 		}
 
 	if(i>1)
@@ -501,7 +469,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	if((f->len>1)&& (!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING))) )
 		{
-		int len=sprintf(buf, "%s[%d:%d]", namecache[i],GLOBALS->mvlfacs_vzt_c_3[i].msb, GLOBALS->mvlfacs_vzt_c_3[i].lsb);
+		int len=sprintf(buf, "%s[%d:%d]", namecache[i],node_block[i].msi, node_block[i].lsi);
 		str=malloc_2(len+1);
 
 		if(!GLOBALS->alt_hier_delimeter)
@@ -521,10 +489,10 @@ for(i=0;i<GLOBALS->numfacs;i++)
 			((i!=GLOBALS->numfacs-1)&&(!strcmp(namecache[i], namecache[i+1]))))
 			||
 			(((i!=0)&&(!strcmp(namecache[i], namecache[i-1]))) &&
-			(GLOBALS->mvlfacs_vzt_c_3[i].msb!=-1)&&(GLOBALS->mvlfacs_vzt_c_3[i].lsb!=-1))
+			(node_block[i].msi!=-1)&&(node_block[i].lsi!=-1))
 		)
 		{
-		int len = sprintf(buf, "%s[%d]", namecache[i],GLOBALS->mvlfacs_vzt_c_3[i].msb);
+		int len = sprintf(buf, "%s[%d]", namecache[i],node_block[i].msi);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -565,8 +533,8 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 		if(f->flags&VZT_RD_SYM_F_INTEGER)
 			{
-			GLOBALS->mvlfacs_vzt_c_3[i].msb=31;
-			GLOBALS->mvlfacs_vzt_c_3[i].lsb=0;
+			node_block[i].msi=31;
+			node_block[i].lsi=0;
 			GLOBALS->mvlfacs_vzt_c_3[i].len=32;
 			}
 		}
@@ -579,8 +547,6 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	if((f->len>1)||(f->flags&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
 		{
 		n->extvals = 1;
-		n->msi = GLOBALS->mvlfacs_vzt_c_3[i].msb;
-		n->lsi = GLOBALS->mvlfacs_vzt_c_3[i].lsb;
 		}
                  
         n->head.time=-1;        /* mark 1st node as negative time */
@@ -602,9 +568,7 @@ pclose(GLOBALS->extload);
 /* SPLASH */                            splash_sync(2, 5);  
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 
-create_hier_array();
-
-if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
+if(GLOBALS->fast_tree_sort)
         {
         for(i=0;i<GLOBALS->numfacs;i++)
                 {
@@ -679,31 +643,13 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 	for(i=0;i<GLOBALS->numfacs;i++)	
 		{
 		char *nf = GLOBALS->facs[i]->name;
-		int was_packed;
-		char *recon = hier_decompress_flagged(nf, &was_packed);
-
-		if(was_packed)
-		        {
-		        build_tree_from_name(recon, i);
-		        free_2(recon);
-		        }
-		        else
-		        {
-		        build_tree_from_name(nf, i);
-		        }        
+	        build_tree_from_name(nf, i);
 		}
 /* SPLASH */                            splash_sync(5, 5);  
 	treegraft(&GLOBALS->treeroot);
 	treesort(GLOBALS->treeroot, NULL);
 	}
 
-if(GLOBALS->prev_hier_uncompressed_name) 
-	{
-	free_2(GLOBALS->prev_hier_uncompressed_name);
-	GLOBALS->prev_hier_uncompressed_name = NULL; 
-	}
-
-
 if(skip_start || skip_end)
 	{
 	TimeType b_start, b_end;
@@ -771,9 +717,13 @@ if(!(f->flags&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
 	}
 else if(f->flags&VZT_RD_SYM_F_DOUBLE)
 	{
+#ifdef WAVE_HAS_H_DOUBLE
+	sscanf(*value, "%lg", &htemp->v.h_double);
+#else
 	double *d = malloc_2(sizeof(double));
 	sscanf(*value, "%lg", d);
 	htemp->v.h_vector = (char *)d;
+#endif
 	htemp->flags = HIST_REAL;
 	}
 else	/* string */
@@ -854,7 +804,7 @@ fprintf(stderr, EXTLOAD"Import: %s\n", np->nname);
 /* new stuff */
 len = np->mv.mvlfac->len;
 
-if((f->array_height <= 1)&&(last_modification_check())) /* sorry, arrays not supported */
+if(last_modification_check()) /* place array height check here in an "&&" branch, sorry, arrays not supported */
 	{
 	char sbuff[65537];
 	TimeType tim;
@@ -1005,8 +955,14 @@ if(nold!=np)
 #endif
 
 /*
- * $Id: extload.c,v 1.11 2010/05/27 06:56:39 gtkwave Exp $
+ * $Id: extload.c,v 1.13 2011/01/13 17:20:39 gtkwave Exp $
  * $Log: extload.c,v $
+ * Revision 1.13  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
+ * Revision 1.12  2011/01/07 20:17:10  gtkwave
+ * remove redundant fields from struct fac
+ *
  * Revision 1.11  2010/05/27 06:56:39  gtkwave
  * printf warning fixes
  *
