@@ -12,7 +12,7 @@
 #ifndef WAVE_EXTRDR_H
 #define WAVE_EXTRDR_H
 
-#ifndef _MSC_VER
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
 #endif
 
@@ -26,8 +26,11 @@ void 		import_extload_trace(nptr np);
 #endif
 
 /*
- * $Id: extload.h,v 1.1 2009/01/27 07:04:28 gtkwave Exp $
+ * $Id: extload.h,v 1.2 2010/04/27 23:10:56 gtkwave Exp $
  * $Log: extload.h,v $
+ * Revision 1.2  2010/04/27 23:10:56  gtkwave
+ * made inttype.h inclusion conditional
+ *
  * Revision 1.1  2009/01/27 07:04:28  gtkwave
  * added extload external process loader capability
  *
