@@ -63,10 +63,10 @@ int len;
 if(s) 
 	{
 	char *s2 = s + strlen(s) - 1;
-	while(isspace(*s2) && (s2 != s)) { *s2 = 0; s2--; }
+	while(isspace((int)(unsigned char)*s2) && (s2 != s)) { *s2 = 0; s2--; }
 
 	s2 = s;
-	while(*s2 && isspace(*s2)) { s2++; }
+	while(*s2 && isspace((int)(unsigned char)*s2)) { s2++; }
 
 	if((len = strlen(s2)))
 		{
@@ -120,8 +120,11 @@ return(stripspaces(s));
 }
 
 /*
- * $Id: fgetdynamic.c,v 1.4 2009/12/15 23:40:59 gtkwave Exp $
+ * $Id: fgetdynamic.c,v 1.5 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: fgetdynamic.c,v $
+ * Revision 1.5  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
  * Revision 1.4  2009/12/15 23:40:59  gtkwave
  * removed old style scripts; also removed tempfiles for Tcl args
  *
