@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2009.
+ * Copyright (c) Tony Bybell 2009-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@
 #include "hierpack.h"
 #include "fst.h"
 
+
 #define FST_RDLOAD "FSTLOAD | "
 
 /******************************************************************/
@@ -41,8 +42,12 @@
  * bookkeeping void* pointers found in the malloc_2/free_2 routines in
  * debug.c)
  */
+#ifdef _WAVE_HAVE_JUDY
+#define FST_DOUBLE_GRANULARITY ( (4*1024) / sizeof(double) )
+#else
 #define FST_DOUBLE_GRANULARITY ( ( (4*1024)-(2*sizeof(void *)) ) / sizeof(double) )
-                 
+#endif     
+            
 static void *double_slab_calloc(void)
 {
 if(GLOBALS->double_curr_fst==GLOBALS->double_fini_fst)
@@ -53,11 +58,91 @@ if(GLOBALS->double_curr_fst==GLOBALS->double_fini_fst)
 
 return((void *)(GLOBALS->double_curr_fst++));
 }  
-  
+
+/*
+ * reverse equality mem compare
+ */
+static int memrevcmp(int i, const char *s1, const char *s2)
+{
+i--;
+for(;i>=0;i--)
+        {
+        if(s1[i] != s2[i]) break;
+        }
+
+return(i+1);
+}
+
+
+
+/* 
+ * fast itoa for decimal numbers
+ */
+static char* itoa_2(int value, char* result)
+{
+char* ptr = result, *ptr1 = result, tmp_char;
+int tmp_value;
+
+do {
+        tmp_value = value;
+        value /= 10;
+        *ptr++ = "9876543210123456789" [9 + (tmp_value - value * 10)];
+} while ( value );
+
+if (tmp_value < 0) *ptr++ = '-';
+result = ptr;
+*ptr-- = '\0';
+while(ptr1 < ptr) {
+        tmp_char = *ptr;
+        *ptr--= *ptr1;
+        *ptr1++ = tmp_char;
+}
+return(result);
+}
+
+
+/*
+ * preformatted sprintf statements which remove parsing latency
+ */
+static int sprintf_2_sd(char *s, char *c, int d)
+{
+char *s2 = s;
+
+while(*c)
+        {
+        *(s2++) = *(c++);
+        }
+*(s2++) = '[';
+s2 = itoa_2(d, s2);
+*(s2++) = ']';
+*s2 = 0;
+
+return(s2 - s);
+}
+
+
+static int sprintf_2_sdd(char *s, char *c, int d, int d2)
+{
+char *s2 = s;
+
+while(*c)
+        {
+        *(s2++) = *(c++);
+        }
+*(s2++) = '[';
+s2 = itoa_2(d, s2);
+*(s2++) = ':';
+s2 = itoa_2(d2, s2);
+*(s2++) = ']';
+*s2 = 0;
+
+return(s2 - s);
+}
+
 /******************************************************************/
 
 
-static struct fstHier *extractNextVar(void *xc, int *msb, int *lsb, char **nam)
+static struct fstHier *extractNextVar(void *xc, int *msb, int *lsb, char **nam, int *namlen, int *nnam_max)
 {
 struct fstHier *h;
 const char *pnts;
@@ -72,6 +157,7 @@ while((h = fstReaderIterateHier(xc)))
                 {
                 case FST_HT_SCOPE:
                         GLOBALS->fst_scope_name = fstReaderPushScope(xc, h->u.scope.name, GLOBALS->mod_tree_parent);
+			GLOBALS->fst_scope_name_len = fstReaderGetCurrentScopeLen(xc);
 
 			switch(h->u.scope.typ)
 				{
@@ -83,16 +169,22 @@ while((h = fstReaderIterateHier(xc)))
 				default:			ttype = TREE_UNKNOWN; break;
 				}
 
-			allocate_and_decorate_module_tree_node(ttype, h->u.scope.name);
+			allocate_and_decorate_module_tree_node(ttype, h->u.scope.name, h->u.scope.component,  h->u.scope.name_length, h->u.scope.component_length);
                         break;
                 case FST_HT_UPSCOPE:
 			GLOBALS->mod_tree_parent = fstReaderGetCurrentScopeUserInfo(xc);
                         GLOBALS->fst_scope_name = fstReaderPopScope(xc);
+			GLOBALS->fst_scope_name_len = fstReaderGetCurrentScopeLen(xc);
                         break;
                 case FST_HT_VAR:
-                        GLOBALS->fst_scope_name = fstReaderGetCurrentFlatScope(xc);
+                        /* GLOBALS->fst_scope_name = fstReaderGetCurrentFlatScope(xc); */
+			/* GLOBALS->fst_scope_name_len = fstReaderGetCurrentScopeLen(xc); */
 
-			s = malloc_2(strlen(h->u.var.name) + 1);
+			if(h->u.var.name_length > (*nnam_max))
+				{
+				free_2(*nam); *nam = malloc_2(((*nnam_max) = h->u.var.name_length) + 1);
+				}
+			s = *nam;
 			pnts = h->u.var.name;
 			pntd = s;
 			while(*pnts)
@@ -107,7 +199,7 @@ while((h = fstReaderIterateHier(xc)))
 					}
 				pnts++;
 				}			
-			*pntd = 0;
+			*pntd = 0; *namlen = pntd - s;
 
 			if(!lb_last)
 				{
@@ -158,13 +250,21 @@ while((h = fstReaderIterateHier(xc)))
 					}
 				}			
 
-			if(lb_last) *lb_last = 0;
+			if(lb_last) 
+				{ 
+				*lb_last = 0; 
+				if((lb_last - s) < (*namlen)) 
+					{ 
+					*namlen = lb_last - s; 
+					} 
+				}
 			*nam = s;
 			return(h);
                         break;
                 }
         }
 
+*namlen = 0;
 *nam = NULL;
 return(NULL);
 }
@@ -172,10 +272,10 @@ return(NULL);
 
 static void fst_append_graft_chain(int len, char *nam, int which, struct tree *par)
 {
-struct tree *t = calloc_2(1, sizeof(struct tree) + len);
+struct tree *t = talloc_2(sizeof(struct tree) + len);
 
-strcpy(t->name, nam);
-t->which = which;
+memcpy(t->name, nam, len+1);
+t->t_which = which;
 
 t->child = par;
 t->next = GLOBALS->terminals_tchain_tree_c_1;
@@ -198,11 +298,16 @@ struct symbol *sym_block = NULL;
 struct Node *node_block = NULL;
 struct fstHier *h = NULL;
 int msb, lsb;
-char *nnam = NULL, *pnam = NULL, *pnam2 = NULL;
+char *nnam = NULL;
 uint32_t activity_idx, num_activity_changes;
-struct tree *npar = NULL, *ppar = NULL;
+struct tree *npar = NULL;
 char **f_name = NULL;
+int   *f_name_len = NULL, *f_name_max_len = NULL;
 int allowed_to_autocoalesce;
+int nnam_max = 0;
+
+int f_name_build_buf_len = 128;
+char *f_name_build_buf = malloc_2(f_name_build_buf_len + 1);
 
 GLOBALS->fst_fst_c_1 = fstReaderOpen(fname);
 if(!GLOBALS->fst_fst_c_1)
@@ -220,15 +325,29 @@ if(!allowed_to_autocoalesce)
 scale=(signed char)fstReaderGetTimescale(GLOBALS->fst_fst_c_1);
 exponent_to_time_scale(scale);
 
+f_name = calloc_2(F_NAME_MODULUS+1,sizeof(char *));
+f_name_len = calloc_2(F_NAME_MODULUS+1,sizeof(int));
+f_name_max_len = calloc_2(F_NAME_MODULUS+1,sizeof(int));
+
+nnam_max = 16;
+nnam = malloc_2(nnam_max);
+
 GLOBALS->numfacs=fstReaderGetVarCount(GLOBALS->fst_fst_c_1);
 GLOBALS->mvlfacs_fst_c_3=(struct fac *)calloc_2(GLOBALS->numfacs,sizeof(struct fac));
-f_name = calloc_2(F_NAME_MODULUS+1,sizeof(char *));
 GLOBALS->fst_table_fst_c_1=(struct lx2_entry *)calloc_2(GLOBALS->numfacs, sizeof(struct lx2_entry));
 sym_block = (struct symbol *)calloc_2(GLOBALS->numfacs, sizeof(struct symbol));
 node_block=(struct Node *)calloc_2(GLOBALS->numfacs,sizeof(struct Node));
+GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 GLOBALS->mvlfacs_fst_alias = calloc_2(GLOBALS->numfacs,sizeof(fstHandle));
 GLOBALS->mvlfacs_fst_rvs_alias = calloc_2(GLOBALS->numfacs,sizeof(fstHandle));
 
+if(!GLOBALS->fast_tree_sort)
+	{
+	GLOBALS->do_hier_compress = 0;
+	}
+
+init_facility_pack();
+
 fprintf(stderr, FST_RDLOAD"Processing %d facs.\n", GLOBALS->numfacs);
 /* SPLASH */                            splash_sync(1, 5);
 
@@ -292,72 +411,72 @@ if(!GLOBALS->hier_was_explicitly_set)    /* set default hierarchy split char */
         GLOBALS->hier_delimeter='.';
         }
 
-if(GLOBALS->numfacs)
-	{
+for(i=0;i<GLOBALS->numfacs;i++)
+        {
+	char buf[65537];
+	char *str;	
+	struct fac *f;
+	int hier_len, name_len, tlen;
+	unsigned char nvt;
+	int longest_nam_candidate = 0;
 	char *fnam;
-	char *pnt = NULL;
-	int was_packed = 0;
-	int hier_len, name_len;
 
-	h = extractNextVar(GLOBALS->fst_fst_c_1, &msb, &lsb, &nnam);
+	h = extractNextVar(GLOBALS->fst_fst_c_1, &msb, &lsb, &nnam, &name_len, &nnam_max);
 	if(!h)
 		{
-		fstReaderClose(GLOBALS->fst_fst_c_1); GLOBALS->fst_fst_c_1 = NULL;
-		return(LLDescriptor(0));
+		/* this should never happen */
+		fstReaderIterateHierRewind(GLOBALS->fst_fst_c_1);
+		h = extractNextVar(GLOBALS->fst_fst_c_1, &msb, &lsb, &nnam, &name_len, &nnam_max);
 		}
-
 	npar = GLOBALS->mod_tree_parent;
-	name_len = strlen(nnam);
-	hier_len = GLOBALS->fst_scope_name ? strlen(GLOBALS->fst_scope_name) : 0;
+	hier_len = GLOBALS->fst_scope_name ? GLOBALS->fst_scope_name_len : 0;
 	if(hier_len)
 		{
-		fnam = malloc_2(hier_len + 1 + name_len + 1);
+		tlen = hier_len + 1 + name_len;
+		if(tlen > f_name_max_len[i&F_NAME_MODULUS])
+			{
+			if(f_name[i&F_NAME_MODULUS]) free_2(f_name[i&F_NAME_MODULUS]);
+			f_name_max_len[i&F_NAME_MODULUS] = tlen;
+			fnam = malloc_2(tlen + 1);
+			}
+			else
+			{
+			fnam = f_name[i&F_NAME_MODULUS];
+			}
+
 		memcpy(fnam, GLOBALS->fst_scope_name, hier_len);
 		fnam[hier_len] = GLOBALS->hier_delimeter;
 		memcpy(fnam + hier_len + 1, nnam, name_len + 1);
 		}
 		else
 		{
-		fnam = malloc_2(name_len + 1);
+		tlen = name_len;
+		if(tlen > f_name_max_len[i&F_NAME_MODULUS])
+			{
+			if(f_name[i&F_NAME_MODULUS]) free_2(f_name[i&F_NAME_MODULUS]);
+			f_name_max_len[i&F_NAME_MODULUS] = tlen;
+			fnam = malloc_2(tlen + 1);
+			}
+			else
+			{
+			fnam = f_name[i&F_NAME_MODULUS];
+			}
+
 		memcpy(fnam, nnam, name_len + 1);
 		}
-	/* free_2(nnam); ...deallocated through pnam */
-	
-	if(GLOBALS->do_hier_compress)
-		{
-		pnt = hier_compress(fnam, HIERPACK_ADD, &was_packed);
-		}
 
-	if(was_packed)
-		{
-		f_name[0] = pnt;
-		free_2(fnam);
-		}
-		else
-		{
-		f_name[0]=fnam;
-		}
-	}
+	f_name[i&F_NAME_MODULUS] = fnam;
+	f_name_len[i&F_NAME_MODULUS] = tlen;
 
-
-for(i=0;i<GLOBALS->numfacs;i++)
-        {
-	char buf[65537];
-	char *str;	
-	struct fac *f;
-	int hier_len, name_len;
-	unsigned char nvt;
-
-	GLOBALS->mvlfacs_fst_c_3[i].array_height = 1;
         if((h->u.var.length > 1) && (msb == -1) && (lsb == -1))
 		{
-		GLOBALS->mvlfacs_fst_c_3[i].msb = h->u.var.length - 1;
-		GLOBALS->mvlfacs_fst_c_3[i].lsb = 0;
+		node_block[i].msi = h->u.var.length - 1;
+		node_block[i].lsi = 0;
 		}
 		else
 		{	
-		GLOBALS->mvlfacs_fst_c_3[i].msb = msb;
-		GLOBALS->mvlfacs_fst_c_3[i].lsb = lsb;
+		node_block[i].msi = msb;
+		node_block[i].lsi = lsb;
 		}
 	GLOBALS->mvlfacs_fst_c_3[i].len = h->u.var.length; 
 
@@ -421,85 +540,40 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	
 	if(h->u.var.is_alias)
 		{
-		GLOBALS->mvlfacs_fst_alias[i] = h->u.var.handle - 1; /* subtract 1 to scale it with gtkwave-style numbering */
+		GLOBALS->mvlfacs_fst_c_3[i].node_alias = h->u.var.handle - 1; /* subtract 1 to scale it with gtkwave-style numbering */
 		GLOBALS->mvlfacs_fst_c_3[i].flags |= VZT_RD_SYM_F_ALIAS;
 		numalias++;
 		}
 	else
 		{
 		GLOBALS->mvlfacs_fst_rvs_alias[numvars] = i;
-		GLOBALS->mvlfacs_fst_alias[i] = numvars;
+		GLOBALS->mvlfacs_fst_c_3[i].node_alias = numvars;
 		numvars++;
 		}
 
-	if(pnam2) { free_2(pnam2); }
-	pnam2 = pnam;
-	pnam = nnam;
-
-	ppar = npar;
-
-	if(i!=(GLOBALS->numfacs-1))
-		{
-		char *fnam;
-		char *pnt = NULL;
-		int was_packed = 0;
-
-		h = extractNextVar(GLOBALS->fst_fst_c_1, &msb, &lsb, &nnam);
-		if(!h)
-			{
-			/* this should never happen */
-			fstReaderIterateHierRewind(GLOBALS->fst_fst_c_1);
-			h = extractNextVar(GLOBALS->fst_fst_c_1, &msb, &lsb, &nnam);
-			}
-		npar = GLOBALS->mod_tree_parent;
-		name_len = strlen(nnam);
-		hier_len = GLOBALS->fst_scope_name ? strlen(GLOBALS->fst_scope_name) : 0;
-		if(hier_len)
-			{
-			fnam = malloc_2(hier_len + 1 + name_len + 1);
-			memcpy(fnam, GLOBALS->fst_scope_name, hier_len);
-			fnam[hier_len] = GLOBALS->hier_delimeter;
-			memcpy(fnam + hier_len + 1, nnam, name_len + 1);
-			}
-			else
-			{
-			fnam = malloc_2(name_len + 1);
-			memcpy(fnam, nnam, name_len + 1);
-			}
-		/* free_2(nnam); ...deallocated through pnam */
-
-		if(GLOBALS->do_hier_compress)
-			{
-			pnt = hier_compress(fnam, HIERPACK_ADD, &was_packed);
-			}
-
-		if(was_packed)
-			{
-			f_name[(i+1)&F_NAME_MODULUS] = pnt;
-			free_2(fnam);
-			}
-			else
-			{
-			f_name[(i+1)&F_NAME_MODULUS]=fnam;
-			}
-		}
-
-	if(i>1)
-		{
-		free_2(f_name[(i-2)&F_NAME_MODULUS]);
-		f_name[(i-2)&F_NAME_MODULUS] = NULL;
-		}
-
 	f=GLOBALS->mvlfacs_fst_c_3+i;
 
 	if((f->len>1)&& (!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING))) )
 		{
-		int len=sprintf(buf, "%s[%d:%d]", f_name[(i)&F_NAME_MODULUS],GLOBALS->mvlfacs_fst_c_3[i].msb, GLOBALS->mvlfacs_fst_c_3[i].lsb);
-		str=malloc_2(len+1);
+		int len=sprintf_2_sdd(buf, f_name[(i)&F_NAME_MODULUS],node_block[i].msi, node_block[i].lsi);
+		longest_nam_candidate = len;
+
+		if(!GLOBALS->do_hier_compress)
+			{
+			str=malloc_2(len+1);
+			}
+			else
+			{
+			if(len > f_name_build_buf_len)
+				{
+				free_2(f_name_build_buf); f_name_build_buf = malloc_2((f_name_build_buf_len=len)+1);
+				}
+			str = f_name_build_buf;
+			}
 
 		if(!GLOBALS->alt_hier_delimeter)
 			{
-			strcpy(str, buf);
+			memcpy(str, buf, len+1);
 			}
 			else
 			{
@@ -509,79 +583,129 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	        symadd_name_exists_sym_exists(s,str,0);
 		prevsymroot = prevsym = NULL;
 
-		len = sprintf(buf, "%s[%d:%d]", pnam,GLOBALS->mvlfacs_fst_c_3[i].msb, GLOBALS->mvlfacs_fst_c_3[i].lsb);
-		if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress)) fst_append_graft_chain(len, buf, i, ppar);
+		if(GLOBALS->fast_tree_sort) 
+			{
+			len = sprintf_2_sdd(buf, nnam,node_block[i].msi, node_block[i].lsi);
+			fst_append_graft_chain(len, buf, i, npar);
+			}
 		}
-	else if ( 
-			((f->len==1)&&(!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))&&
-			((i!=GLOBALS->numfacs-1)&&(!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i+1)&F_NAME_MODULUS]))))
-			||
-			(((i!=0)&&(!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i-1)&F_NAME_MODULUS]))) &&
-			(GLOBALS->mvlfacs_fst_c_3[i].msb!=-1)&&(GLOBALS->mvlfacs_fst_c_3[i].lsb!=-1))
-		)
+	else
 		{
-		int len = sprintf(buf, "%s[%d]", f_name[(i)&F_NAME_MODULUS],GLOBALS->mvlfacs_fst_c_3[i].msb);
-		str=malloc_2(len+1);
-		if(!GLOBALS->alt_hier_delimeter)
-			{
-			strcpy(str, buf);
-			}
-			else
-			{
-			strcpy_vcdalt(str, buf, GLOBALS->alt_hier_delimeter);
-			}
-		s=&sym_block[i];
-	        symadd_name_exists_sym_exists(s,str,0);
-		if((allowed_to_autocoalesce)&&(prevsym)&&(i>0)&&(!strcmp(f_name[(i)&F_NAME_MODULUS], f_name[(i-1)&F_NAME_MODULUS]))&&(!strchr(f_name[(i)&F_NAME_MODULUS], '\\')))	/* allow chaining for search functions.. */
-			{
-			prevsym->vec_root = prevsymroot;
-			prevsym->vec_chain = s;
-			s->vec_root = prevsymroot;
-			prevsym = s;
-			}
-			else
-			{
-			prevsymroot = prevsym = s;
-			}
+		int gatecmp = (f->len==1) && (!(f->flags&(VZT_RD_SYM_F_INTEGER|VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING))) && (node_block[i].msi!=-1) && (node_block[i].lsi!=-1);
+		int revcmp = gatecmp && (i) && (f_name_len[(i)&F_NAME_MODULUS] == f_name_len[(i-1)&F_NAME_MODULUS]) && (!memrevcmp(f_name_len[(i)&F_NAME_MODULUS], f_name[(i)&F_NAME_MODULUS], f_name[(i-1)&F_NAME_MODULUS]));
 
-		len = sprintf(buf, "%s[%d]", pnam,GLOBALS->mvlfacs_fst_c_3[i].msb);
-		if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress)) fst_append_graft_chain(len, buf, i, ppar);
+		if(gatecmp)
+			{
+			int len = sprintf_2_sd(buf, f_name[(i)&F_NAME_MODULUS],node_block[i].msi);
+
+			longest_nam_candidate = len;
+			if(!GLOBALS->do_hier_compress)
+				{
+				str=malloc_2(len+1);
+				}
+				else
+				{
+				if(len > f_name_build_buf_len)
+					{
+					free_2(f_name_build_buf); f_name_build_buf = malloc_2((f_name_build_buf_len=len)+1);
+					}
+				str = f_name_build_buf;
+				}
+
+			if(!GLOBALS->alt_hier_delimeter)
+				{
+				memcpy(str, buf, len+1);
+				}
+				else
+				{
+				strcpy_vcdalt(str, buf, GLOBALS->alt_hier_delimeter);
+				}
+			s=&sym_block[i];
+		        symadd_name_exists_sym_exists(s,str,0);
+			if((allowed_to_autocoalesce)&&(prevsym)&&(revcmp)&&(!strchr(f_name[(i)&F_NAME_MODULUS], '\\')))	/* allow chaining for search functions.. */
+				{
+				prevsym->vec_root = prevsymroot;
+				prevsym->vec_chain = s;
+				s->vec_root = prevsymroot;
+				prevsym = s;
+				}
+				else
+				{
+				prevsymroot = prevsym = s;
+				}
+
+			if(GLOBALS->fast_tree_sort) 
+				{
+				len = sprintf_2_sd(buf, nnam,node_block[i].msi);
+				fst_append_graft_chain(len, buf, i, npar);
+				}
+			}
+			else
+			{
+			int len = f_name_len[(i)&F_NAME_MODULUS];
+
+			longest_nam_candidate = len;
+			if(!GLOBALS->do_hier_compress)
+				{
+				str=malloc_2(len+1);
+				}
+				else
+				{
+				if(len > f_name_build_buf_len)
+					{
+					free_2(f_name_build_buf); f_name_build_buf = malloc_2((f_name_build_buf_len=len)+1);
+					}
+				str = f_name_build_buf;
+				}
+
+			if(!GLOBALS->alt_hier_delimeter)
+				{
+				memcpy(str, f_name[(i)&F_NAME_MODULUS], len+1);
+				}
+				else
+				{
+				strcpy_vcdalt(str, f_name[(i)&F_NAME_MODULUS], GLOBALS->alt_hier_delimeter);
+				}
+			s=&sym_block[i];
+		        symadd_name_exists_sym_exists(s,str,0);
+			prevsymroot = prevsym = NULL;
+	
+			if(f->flags&VZT_RD_SYM_F_INTEGER)
+				{
+				node_block[i].msi=31;
+				node_block[i].lsi=0;
+				GLOBALS->mvlfacs_fst_c_3[i].len=32;
+				}
+	
+			if(GLOBALS->fast_tree_sort) 
+				{
+				fst_append_graft_chain(strlen(nnam), nnam, i, npar);
+				}
+			}
+		}
+		
+        if(longest_nam_candidate > GLOBALS->longestname) GLOBALS->longestname = longest_nam_candidate;
+
+        GLOBALS->facs[i]=&sym_block[i];
+        n=&node_block[i];
+
+	if(GLOBALS->do_hier_compress)
+		{
+		n->nname = compress_facility((unsigned char *)s->name, longest_nam_candidate);
+		/* free_2(s->name); ...removed as f_name_build_buf is now used */
+		s->name = n->nname;	
 		}
 		else
 		{
-		str=malloc_2(strlen(f_name[(i)&F_NAME_MODULUS])+1);
-		if(!GLOBALS->alt_hier_delimeter)
-			{
-			strcpy(str, f_name[(i)&F_NAME_MODULUS]);
-			}
-			else
-			{
-			strcpy_vcdalt(str, f_name[(i)&F_NAME_MODULUS], GLOBALS->alt_hier_delimeter);
-			}
-		s=&sym_block[i];
-	        symadd_name_exists_sym_exists(s,str,0);
-		prevsymroot = prevsym = NULL;
-
-		if(f->flags&VZT_RD_SYM_F_INTEGER)
-			{
-			GLOBALS->mvlfacs_fst_c_3[i].msb=31;
-			GLOBALS->mvlfacs_fst_c_3[i].lsb=0;
-			GLOBALS->mvlfacs_fst_c_3[i].len=32;
-			}
-
-		if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress)) fst_append_graft_chain(strlen(pnam), pnam, i, ppar);
+		n->nname=s->name;
 		}
-		
-        n=&node_block[i];
-        n->nname=s->name;
+
         n->mv.mvlfac = GLOBALS->mvlfacs_fst_c_3+i;
 	GLOBALS->mvlfacs_fst_c_3[i].working_node = n;
 	n->vartype = nvt;
 
 	if((f->len>1)||(f->flags&(VZT_RD_SYM_F_DOUBLE|VZT_RD_SYM_F_STRING)))
 		{
-		n->msi = GLOBALS->mvlfacs_fst_c_3[i].msb;
-		n->lsi = GLOBALS->mvlfacs_fst_c_3[i].lsb;
 		n->extvals = 1;
 		}
                  
@@ -590,8 +714,8 @@ for(i=0;i<GLOBALS->numfacs;i++)
         s->n=n;
         }			/* for(i) of facs parsing */
 
-if(pnam2) { free_2(pnam2); pnam2 = NULL; }
-if(pnam) { free_2(pnam); pnam = NULL; }
+if(nnam) { free_2(nnam); nnam = NULL; }
+if(f_name_build_buf) { free_2(f_name_build_buf); f_name_build_buf = NULL; }
 
 for(i=0;i<=F_NAME_MODULUS;i++)
 	{
@@ -602,6 +726,12 @@ for(i=0;i<=F_NAME_MODULUS;i++)
 		}
 	}
 free_2(f_name); f_name = NULL;
+free_2(f_name_len); f_name_len = NULL;
+
+if(numvars != GLOBALS->numfacs) { GLOBALS->mvlfacs_fst_rvs_alias = realloc_2(GLOBALS->mvlfacs_fst_rvs_alias, numvars * sizeof(fstHandle)); }
+
+freeze_facility_pack();
+iter_through_comp_name_table();
 
 fprintf(stderr, FST_RDLOAD"Built %d signal%s and %d alias%s.\n", 
 	numvars, (numvars == 1) ? "" : "s", 
@@ -609,44 +739,33 @@ fprintf(stderr, FST_RDLOAD"Built %d signal%s and %d alias%s.\n",
 
 GLOBALS->fst_maxhandle = numvars;
 
-/* SPLASH */                            splash_sync(2, 5);  
-GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
-
-create_hier_array();
-
-if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
+if(GLOBALS->fast_tree_sort)
         {
-        for(i=0;i<GLOBALS->numfacs;i++)
-                {
-                int len;
-                GLOBALS->facs[i]=&sym_block[i]; 
-                if((len=strlen(GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
-                }
-                                
-/* SPLASH */                            splash_sync(3, 5);  
+/* SPLASH */                            splash_sync(2, 5);  
         fprintf(stderr, FST_RDLOAD"Building facility hierarchy tree.\n");
-                                         
+
         init_tree();
         treegraft(&GLOBALS->treeroot);
 
-/* SPLASH */                            splash_sync(4, 5);  
+/* SPLASH */                            splash_sync(3, 5);  
                                 
         fprintf(stderr, FST_RDLOAD"Sorting facility hierarchy tree.\n");
         treesort(GLOBALS->treeroot, NULL);
-/* SPLASH */                            splash_sync(5, 5);  
+/* SPLASH */                            splash_sync(4, 5);  
         order_facs_from_treesort(GLOBALS->treeroot, &GLOBALS->facs);
+
+/* SPLASH */                            splash_sync(5, 5);  
         GLOBALS->facs_are_sorted=1;
         }
         else
 	{
+/* SPLASH */                            splash_sync(2, 5);  
 	for(i=0;i<GLOBALS->numfacs;i++)
 		{
 		char *subst, ch;
-		int len;
 		int esc = 0;
 
-		GLOBALS->facs[i]=&sym_block[i];
-	        if((len=strlen(subst=GLOBALS->facs[i]->name))>GLOBALS->longestname) GLOBALS->longestname=len;
+	        subst=GLOBALS->facs[i]->name;
 		while((ch=(*subst)))
 			{	
 #ifdef WAVE_HIERFIX
@@ -686,18 +805,7 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 	for(i=0;i<GLOBALS->numfacs;i++)	
 		{
 		char *nf = GLOBALS->facs[i]->name;
-		int was_packed;
-		char *recon = hier_decompress_flagged(nf, &was_packed);
-                
-		if(was_packed)   
-		        {
-		        build_tree_from_name(recon, i);
-		        free_2(recon);
-		        }
-		        else
-		        {
-		        build_tree_from_name(nf, i);
-		        }
+	        build_tree_from_name(nf, i);
 		}
 /* SPLASH */                            splash_sync(5, 5);
 	if(GLOBALS->escaped_names_found_vcd_c_1)
@@ -721,12 +829,6 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 	        }
 	}
 
-if(GLOBALS->prev_hier_uncompressed_name) 
-	{
-	free_2(GLOBALS->prev_hier_uncompressed_name);
-	GLOBALS->prev_hier_uncompressed_name = NULL; 
-	}
-
 #if 0
 {
 int num_dups = 0;
@@ -907,7 +1009,11 @@ else if(f->flags&VZT_RD_SYM_F_DOUBLE)
 	{
 	if((l2e->histent_curr)&&(l2e->histent_curr->v.h_vector)) /* remove duplicate values */
 		{
+#ifdef WAVE_HAS_H_DOUBLE
+		if(!memcmp(&l2e->histent_curr->v.h_double, value, sizeof(double)))
+#else
 		if(!memcmp(l2e->histent_curr->v.h_vector, value, sizeof(double)))
+#endif
 			{
 			return;
 			}
@@ -924,8 +1030,12 @@ else if(f->flags&VZT_RD_SYM_F_DOUBLE)
 	*/
 
 	htemp = histent_calloc();
+#ifdef WAVE_HAS_H_DOUBLE
+	memcpy(&htemp->v.h_double, value, sizeof(double));
+#else
 	htemp->v.h_vector = double_slab_calloc();
 	memcpy(htemp->v.h_vector, value, sizeof(double));
+#endif
 	htemp->flags = HIST_REAL;
 	}
 else	/* string */
@@ -1019,7 +1129,7 @@ if(!(f=np->mv.mvlfac)) return;	/* already imported */
 txidx = f - GLOBALS->mvlfacs_fst_c_3;
 if(np->mv.mvlfac->flags&VZT_RD_SYM_F_ALIAS) 
 	{
-	txidx = GLOBALS->mvlfacs_fst_alias[txidx]; /* this is to map to fstHandles, so even non-aliased are remapped */
+	txidx = GLOBALS->mvlfacs_fst_c_3[txidx].node_alias; /* this is to map to fstHandles, so even non-aliased are remapped */
 	txidx = GLOBALS->mvlfacs_fst_rvs_alias[txidx];
 	np = GLOBALS->mvlfacs_fst_c_3[txidx].working_node;
 
@@ -1035,11 +1145,11 @@ fprintf(stderr, "Import: %s\n", np->nname);
 /* new stuff */
 len = np->mv.mvlfac->len;
 
-if(f->array_height <= 1) /* sorry, arrays not supported, but fst doesn't support them yet either */
+/* check here for array height in future */
 	{
-	fstReaderSetFacProcessMask(GLOBALS->fst_fst_c_1, GLOBALS->mvlfacs_fst_alias[txidx]+1);
+	fstReaderSetFacProcessMask(GLOBALS->fst_fst_c_1, GLOBALS->mvlfacs_fst_c_3[txidx].node_alias+1);
 	fstReaderIterBlocks2(GLOBALS->fst_fst_c_1, fst_callback, fst_callback2, NULL, NULL);
-	fstReaderClrFacProcessMask(GLOBALS->fst_fst_c_1, GLOBALS->mvlfacs_fst_alias[txidx]+1);
+	fstReaderClrFacProcessMask(GLOBALS->fst_fst_c_1, GLOBALS->mvlfacs_fst_c_3[txidx].node_alias+1);
 	}
 
 histent_tail = htemp = histent_calloc();
@@ -1072,10 +1182,13 @@ if(len>1)
 		}
 		else
 		{
+#ifdef WAVE_HAS_H_DOUBLE
+		htemp->v.h_double = strtod("NaN", NULL);
+#else
                 double *d = malloc_2(sizeof(double));
-
                 *d = strtod("NaN", NULL);
                 htemp->v.h_vector = (char *)d;
+#endif
                 htemp->flags = HIST_REAL;
 		}
         htempx = htemp;
@@ -1160,16 +1273,16 @@ if(!(f=np->mv.mvlfac)) return;	/* already imported */
 txidx = f-GLOBALS->mvlfacs_fst_c_3;
 if(np->mv.mvlfac->flags&VZT_RD_SYM_F_ALIAS) 
 	{
-	txidx = GLOBALS->mvlfacs_fst_alias[txidx];
+	txidx = GLOBALS->mvlfacs_fst_c_3[txidx].node_alias;
 	txidx = GLOBALS->mvlfacs_fst_rvs_alias[txidx]; 
 	np = GLOBALS->mvlfacs_fst_c_3[txidx].working_node;
 
 	if(!(np->mv.mvlfac)) return;	/* already imported */
 	}
 
-if(np->mv.mvlfac->array_height <= 1) /* sorry, arrays not supported, but fst doesn't support them yet either */
+/* check here for array height in future */
 	{
-	fstReaderSetFacProcessMask(GLOBALS->fst_fst_c_1, GLOBALS->mvlfacs_fst_alias[txidx]+1);
+	fstReaderSetFacProcessMask(GLOBALS->fst_fst_c_1, GLOBALS->mvlfacs_fst_c_3[txidx].node_alias+1);
 	GLOBALS->fst_table_fst_c_1[txidx].np = np;
 	}
 }
@@ -1244,10 +1357,14 @@ for(txidxi=0;txidxi<GLOBALS->fst_maxhandle;txidxi++)
 				}
 				else
 				{
+#ifdef WAVE_HAS_H_DOUBLE
+				htemp->v.h_double = strtod("NaN", NULL);				
+#else
 				double *d = malloc_2(sizeof(double));
 
 				*d = strtod("NaN", NULL);
 				htemp->v.h_vector = (char *)d;
+#endif
 				htemp->flags = HIST_REAL;
 				htempx = htemp;
 				}
@@ -1317,8 +1434,50 @@ for(txidxi=0;txidxi<GLOBALS->fst_maxhandle;txidxi++)
 }
 
 /*
- * $Id: fst.c,v 1.37 2010/12/19 07:59:10 gtkwave Exp $
+ * $Id: fst.c,v 1.51 2011/01/22 05:42:52 gtkwave Exp $
  * $Log: fst.c,v $
+ * Revision 1.51  2011/01/22 05:42:52  gtkwave
+ * replace some string copies with mem copies
+ *
+ * Revision 1.50  2011/01/22 01:29:24  gtkwave
+ * sourcecode cleanup / warnings fixes
+ *
+ * Revision 1.49  2011/01/21 22:40:28  gtkwave
+ * pass string lengths from api directly to code to avoid length calculations
+ *
+ * Revision 1.48  2011/01/21 21:32:30  gtkwave
+ * remove redundant and repetitive allocations
+ *
+ * Revision 1.47  2011/01/21 21:04:31  gtkwave
+ * signal name processing optimization on reader
+ *
+ * Revision 1.46  2011/01/20 23:34:53  gtkwave
+ * fix to autocoalesce code
+ *
+ * Revision 1.45  2011/01/20 19:07:20  gtkwave
+ * add reverse equality mem compare
+ *
+ * Revision 1.44  2011/01/20 05:35:56  gtkwave
+ * fast tree sort = 0 fix
+ *
+ * Revision 1.43  2011/01/20 02:16:13  gtkwave
+ * remove redundant strlen ops and replace with query function
+ *
+ * Revision 1.42  2011/01/19 06:36:31  gtkwave
+ * added tree allocation pool when misaligned structs are enabled
+ *
+ * Revision 1.41  2011/01/18 00:00:12  gtkwave
+ * preliminary tree component support
+ *
+ * Revision 1.40  2011/01/17 19:24:21  gtkwave
+ * tree modifications to support decorated internal hierarchy nodes
+ *
+ * Revision 1.39  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
+ * Revision 1.38  2011/01/07 20:17:10  gtkwave
+ * remove redundant fields from struct fac
+ *
  * Revision 1.37  2010/12/19 07:59:10  gtkwave
  * warnings fixes
  *
