@@ -18,6 +18,7 @@
 
 #include "vcd.h"
 #include "ae2.h"
+#include "tree_component.h"
 
 TimeType fst_main(char *fname, char *skip_start, char *skip_end);
 void import_fst_trace(nptr np);
@@ -27,8 +28,11 @@ void fst_import_masked(void);
 #endif
 
 /*
- * $Id: fst.h,v 1.2 2010/04/27 23:10:56 gtkwave Exp $
+ * $Id: fst.h,v 1.3 2011/01/18 00:00:12 gtkwave Exp $
  * $Log: fst.h,v $
+ * Revision 1.3  2011/01/18 00:00:12  gtkwave
+ * preliminary tree component support
+ *
  * Revision 1.2  2010/04/27 23:10:56  gtkwave
  * made inttype.h inclusion conditional
  *
