@@ -1,5 +1,5 @@
 /*  GHDL Wavefile reader interface.
-    Copyright (C) 2005-2010 Tristan Gingold and Tony Bybell
+    Copyright (C) 2005-2011 Tristan Gingold and Tony Bybell
 
     GHDL is free software; you can redistribute it and/or modify it under
     the terms of the GNU General Public License as published by the Free
@@ -21,6 +21,7 @@
 #include <config.h>
 #include "ghw.h"
 #include "ghwlib.h"
+#include "tree.h"
 
 /************************ splay ************************/
 
@@ -217,7 +218,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 
 /*
- * preserve tree->which ordering so hierarchy children index pointers don't get corrupted
+ * preserve tree->t_which ordering so hierarchy children index pointers don't get corrupted
  */
 
 static void recurse_tree_build_whichcache(struct tree *t)
@@ -227,7 +228,7 @@ if(t)
 	if(t->child) { recurse_tree_build_whichcache(t->child); }
 	if(t->next) { recurse_tree_build_whichcache(t->next); }
 
-	if(t->which >= 0) GLOBALS->gwt_ghw_c_1 = ghw_insert(t, GLOBALS->gwt_ghw_c_1, t->which, GLOBALS->facs[t->which]);
+	if(t->t_which >= 0) GLOBALS->gwt_ghw_c_1 = ghw_insert(t, GLOBALS->gwt_ghw_c_1, t->t_which, GLOBALS->facs[t->t_which]);
 	}
 }
 
@@ -238,12 +239,12 @@ if(t)
 	if(t->child) { recurse_tree_fix_from_whichcache(t->child); }
 	if(t->next) { recurse_tree_fix_from_whichcache(t->next); }
 
-	if(t->which >= 0) 
+	if(t->t_which >= 0) 
 		{
 		GLOBALS->gwt_ghw_c_1 = ghw_splay(t, GLOBALS->gwt_ghw_c_1);
 		GLOBALS->gwt_corr_ghw_c_1 = ghw_splay(GLOBALS->gwt_ghw_c_1->sym, GLOBALS->gwt_corr_ghw_c_1); /* all facs are in this tree so this is OK */
 
-		t->which = GLOBALS->gwt_corr_ghw_c_1->val_old;				
+		t->t_which = GLOBALS->gwt_corr_ghw_c_1->val_old;				
 		}
 	}
 }
@@ -259,7 +260,7 @@ free_2(t);
 
 
 /*
- * sort facs and also cache/reconstruct tree->which pointers
+ * sort facs and also cache/reconstruct tree->t_which pointers
  */
 static void ghw_sortfacs(void)
 {
@@ -456,9 +457,9 @@ build_hierarchy_type (struct ghw_handler *h, union ghw_type *t,
       GLOBALS->nbr_sig_ref_ghw_c_1++;
       res = (struct tree *) calloc_2(1, sizeof (struct tree) + strlen(pfx));
       strcpy(res->name, (char *)pfx);
-      res->which = *(*sig)++;
+      res->t_which = *(*sig)++;
 
-      s->n = GLOBALS->nxp_ghw_c_1[res->which];
+      s->n = GLOBALS->nxp_ghw_c_1[res->t_which];
       return res;
     case ghdl_rtik_subtype_array:
     case ghdl_rtik_subtype_array_ptr:
@@ -466,7 +467,7 @@ build_hierarchy_type (struct ghw_handler *h, union ghw_type *t,
 	struct tree *r;
 	res = (struct tree *) calloc_2(1, sizeof (struct tree) + strlen(pfx));
 	strcpy(res->name, (char *)pfx);
-	res->which = -1;
+	res->t_which = WAVE_T_WHICH_UNDEFINED_COMPNAME;
 	r = res;
 	build_hierarchy_array (h, t, 0, "", &res, sig);
 	r->child = r->next;
@@ -481,7 +482,7 @@ build_hierarchy_type (struct ghw_handler *h, union ghw_type *t,
 
 	res = (struct tree *) calloc_2(1, sizeof (struct tree) + strlen(pfx));
 	strcpy(res->name, (char *)pfx);
-	res->which = -1;
+	res->t_which = WAVE_T_WHICH_UNDEFINED_COMPNAME;
 
 	last = NULL;
 	for (i = 0; i < t->rec.nbr_fields; i++)
@@ -574,7 +575,7 @@ build_hierarchy (struct ghw_handler *h, struct ghw_hie *hie)
 		}
         }
 
-      t->which = -1;
+      t->t_which = WAVE_T_WHICH_UNDEFINED_COMPNAME;
 
       /* Recurse.  */
       prev = NULL;
@@ -742,16 +743,16 @@ set_fac_name_1 (struct tree *t)
 		}
 	}
 
-      if (t->which >= 0)
+      if (t->t_which >= 0)
 	{
         struct symchain *sc = GLOBALS->firstnode;
 	struct symbol *s = sc->symbol;
 
 	s->name = strdup_2(GLOBALS->fac_name_ghw_c_1);
-	s->n = GLOBALS->nxp_ghw_c_1[t->which];
+	s->n = GLOBALS->nxp_ghw_c_1[t->t_which];
 	if(!s->n->nname) s->n->nname = s->name;
 
-	t->which = GLOBALS->sym_which_ghw_c_1++; /* patch in gtkwave "which" as node is correct */
+	t->t_which = GLOBALS->sym_which_ghw_c_1++; /* patch in gtkwave "which" as node is correct */
 
 	GLOBALS->curnode = GLOBALS->firstnode->next;
 	free_2(GLOBALS->firstnode);
@@ -789,6 +790,9 @@ add_history (struct ghw_handler *h, struct Node *n, int sig_num)
   union ghw_type *sig_type = sig->type;
   int flags;
   int is_vector = 0;
+#ifdef WAVE_HAS_H_DOUBLE
+  int is_double = 0;
+#endif
 
   if (sig_type == NULL)
     return;
@@ -880,10 +884,15 @@ add_history (struct ghw_handler *h, struct Node *n, int sig_num)
       break;
     case ghdl_rtik_type_f64:
       {
+#ifdef WAVE_HAS_H_DOUBLE
+        he->v.h_double = sig->val->f64;
+        is_double = 1;
+#else
 	double *d = malloc_2(sizeof (double));
 	*d = sig->val->f64;
 	he->v.h_vector = (char *)d;
         is_vector = 1;
+#endif
       }
       break;
     case ghdl_rtik_type_i32:
@@ -905,13 +914,31 @@ add_history (struct ghw_handler *h, struct Node *n, int sig_num)
     /* deglitch */
     if(n->curr->time == he->time)
 	{
-        GLOBALS->num_glitches_ghw_c_1++;
+	int gl_add = 0;
+
+	if(n->curr->time) /* filter out time zero glitches */
+		{
+		gl_add = 1;
+		}
+
+        GLOBALS->num_glitches_ghw_c_1 += gl_add;
+
 	if(!(n->curr->flags&HIST_GLITCH))
         	{
-                n->curr->flags|=HIST_GLITCH;    /* set the glitch flag */
-                GLOBALS->num_glitch_regions_ghw_c_1++;
+		if(gl_add)
+			{
+	                n->curr->flags|=HIST_GLITCH;    /* set the glitch flag */
+	                GLOBALS->num_glitch_regions_ghw_c_1++;
+			}
                 }
 
+#ifdef WAVE_HAS_H_DOUBLE
+	if(is_double)
+		{
+		n->curr->v.h_double = he->v.h_double;
+		}
+	else
+#endif
         if(is_vector)
                 {
                 if(n->curr->v.h_vector &&
@@ -1104,7 +1131,9 @@ ghw_main(char *fname)
  struct tree *t = calloc_2(1, sizeof(struct tree) + strlen(base_hier));
  memcpy(t, GLOBALS->treeroot, sizeof(struct tree));
  strcpy(t->name, base_hier);
- free_2(GLOBALS->treeroot);
+#ifndef WAVE_TALLOC_POOL_SIZE
+ free_2(GLOBALS->treeroot); /* if using tree alloc pool, can't deallocate this */
+#endif
  GLOBALS->treeroot = t;
  }
 
@@ -1131,8 +1160,14 @@ ghw_main(char *fname)
 /*******************************************************************************/
 
 /*
- * $Id: ghw.c,v 1.14 2010/03/15 01:17:00 gtkwave Exp $
+ * $Id: ghw.c,v 1.16 2011/01/19 06:36:31 gtkwave Exp $
  * $Log: ghw.c,v $
+ * Revision 1.16  2011/01/19 06:36:31  gtkwave
+ * added tree allocation pool when misaligned structs are enabled
+ *
+ * Revision 1.15  2011/01/17 19:24:21  gtkwave
+ * tree modifications to support decorated internal hierarchy nodes
+ *
  * Revision 1.14  2010/03/15 01:17:00  gtkwave
  * fix abuse of next pointer in ghw symbol creation/traversal
  *
