@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2010.
+ * Copyright (c) Kermin Elliott Fleming 2007-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -268,6 +268,7 @@ NULL, /* fonts_layout */
  */
 NULL, /* fst_fst_c_1 */
 NULL, /* fst_scope_name */
+0, /* fst_scope_name_len */
 0, /* first_cycle_fst_c_3 */
 0, /* last_cycle_fst_c_3 */
 0, /* total_cycles_fst_c_3 */
@@ -319,6 +320,19 @@ NULL, /* gtk_context_bridge_ptr */
 0, /* window_help_c_2 115 */
 
 
+/*
+ * hierpack.c
+ */
+NULL, /* hp_buf */
+NULL, /* hp_offs */
+0, /* hp_prev */
+0, /* hp_buf_siz */
+NULL, /* fmem_buf */
+0, /* fmem_buf_siz */
+0, /* fmem_buf_offs */
+0, /* fmem_uncompressed_siz */
+
+
 /*
  * hiersearch.c
  */
@@ -889,6 +903,22 @@ NULL, /* terminals_tchain_tree_c_1 446 */
 1, /* fast_tree_sort 450 */
 NULL, /* facs2_tree_c_1 451 */
 0, /* facs2_pos_tree_c_1 452 */
+NULL, /* talloc_pool_base */
+0, /* talloc_idx */
+
+
+/*
+ * tree_component.c
+ */
+#ifdef _WAVE_HAVE_JUDY
+NULL, /* comp_name_judy */
+#else
+NULL, /* comp_name_jrb */
+#endif
+NULL, /* comp_name_idx */
+0, /* comp_name_serial */
+0, /* comp_name_total_stringmem */
+0, /* comp_name_longest */
 
 
 /*
@@ -944,6 +974,7 @@ NULL, /* cleanup_treesearch_gtk2_c_8 468 */
 0, /* dnd_tgt_on_signalarea_treesearch_gtk2_c_1 471 */
 0, /* dnd_tgt_on_wavearea_treesearch_gtk2_c_1 */
 NULL, /* dnd_sigview */
+NULL, /* sst_vpaned */
 
 
 /*
@@ -964,12 +995,6 @@ NULL, /* clist_ttranslate_c_2 */
  * vcd.c
  */
 0, /* do_hier_compress */
-NULL, /* hier_pfx */
-0, /* hier_pfx_cnt */
-NULL, /* prev_hier_pfx */
-0, /* prev_hier_pfx_len */
-0, /* prev_hier_pfx_cnt */
-NULL, /* pfx_hier_array */
 NULL, /* prev_hier_uncompressed_name */
 NULL, /* vcd_jmp_buf */
 -1, /* vcd_warning_filesize 472 */
@@ -1344,6 +1369,8 @@ void reload_into_new_context(void)
  gint tree_frame_x = -1, tree_frame_y = -1;
  gdouble tree_vadj_value = 0.0;
  gdouble tree_hadj_value = 0.0;
+ gdouble treeview_vadj_value = 0.0;
+ gdouble treeview_hadj_value = 0.0;
  int fix_from_time = 0, fix_to_time = 0;
  TimeType from_time = LLDescriptor(0), to_time = LLDescriptor(0);
  char timestr[32];
@@ -1403,15 +1430,23 @@ void reload_into_new_context(void)
 #if WAVE_USE_GTK2
  if(GLOBALS->gtk2_tree_frame)
 	{
+	/* upper tree */
 	GtkCList *cl = GTK_CLIST(GLOBALS->ctree_main);
 	GtkAdjustment *vadj = gtk_clist_get_vadjustment(cl);
 	GtkAdjustment *hadj = gtk_clist_get_hadjustment(cl);
 
-	tree_vadj_value = vadj->value;
-	tree_hadj_value = hadj->value;
+	if(vadj) tree_vadj_value = vadj->value;
+	if(hadj) tree_hadj_value = hadj->value;
 
 	tree_frame_x = (GLOBALS->gtk2_tree_frame)->allocation.width;
 	tree_frame_y = (GLOBALS->gtk2_tree_frame)->allocation.height;
+
+	/* lower signal set */
+	vadj = gtk_tree_view_get_vadjustment((GtkTreeView *)GLOBALS->dnd_sigview);
+	hadj = gtk_tree_view_get_hadjustment((GtkTreeView *)GLOBALS->dnd_sigview);
+
+	if(vadj) treeview_vadj_value = vadj->value;
+	if(hadj) treeview_hadj_value = hadj->value;
 	}
 #endif
 
@@ -1553,6 +1588,7 @@ void reload_into_new_context(void)
  new_globals->wavewindow = GLOBALS->wavewindow;
  new_globals->toppanedwindow = GLOBALS->toppanedwindow;
  new_globals->sstpane = GLOBALS->sstpane;
+ new_globals->sst_vpaned = GLOBALS->sst_vpaned;
  new_globals->expanderwindow = GLOBALS->expanderwindow;
  new_globals->signal_hslider = GLOBALS->signal_hslider;
  new_globals->wave_vslider = GLOBALS->wave_vslider;
@@ -1726,9 +1762,6 @@ void reload_into_new_context(void)
  strcpy2_into_new_context(new_globals, &new_globals->repscript_name, &GLOBALS->repscript_name);
  new_globals->repscript_period = GLOBALS->repscript_period;
 
- /* hierarchy handling from vcd.c */
- free_hier_tree();
-
  /* vlist.c */
  if(GLOBALS->vlist_handle)
 	{
@@ -2207,10 +2240,12 @@ void reload_into_new_context(void)
  /* XXX need to destroy/free the old tree widgets. */
  #if GTK_CHECK_VERSION(2,4,0)
  if(!GLOBALS->hide_sst) {
+   gint pane_pos = gtk_paned_get_position(GLOBALS->sst_vpaned);
    gtk_widget_hide(GLOBALS->expanderwindow);
    gtk_container_remove(GTK_CONTAINER(GLOBALS->expanderwindow), GLOBALS->sstpane);
    GLOBALS->sstpane = treeboxframe("SST", GTK_SIGNAL_FUNC(mkmenu_treesearch_cleanup));
    gtk_container_add(GTK_CONTAINER(GLOBALS->expanderwindow), GLOBALS->sstpane);
+   gtk_paned_set_position(GLOBALS->sst_vpaned, pane_pos);
    gtk_widget_show(GLOBALS->expanderwindow);
    if(GLOBALS->dnd_sigview)
         {
@@ -2266,7 +2301,7 @@ void reload_into_new_context(void)
 	{
 	GtkAdjustment *vadj = gtk_clist_get_vadjustment(cl);
 
-	if((tree_vadj_value >= vadj->lower) && (tree_vadj_value <= vadj->upper))
+	if((vadj) && (tree_vadj_value >= vadj->lower) && (tree_vadj_value <= vadj->upper))
 		{ 
 		vadj->value = tree_vadj_value;
 		gtk_clist_set_vadjustment(cl, vadj);
@@ -2280,7 +2315,7 @@ void reload_into_new_context(void)
 	{
 	GtkAdjustment *hadj = gtk_clist_get_hadjustment(cl);
 
-	if((tree_hadj_value >= hadj->lower) && (tree_hadj_value <= hadj->upper))
+	if((hadj) && (tree_hadj_value >= hadj->lower) && (tree_hadj_value <= hadj->upper))
 		{ 
 		hadj->value = tree_hadj_value;
 		gtk_clist_set_hadjustment(cl, hadj);
@@ -2385,6 +2420,46 @@ void reload_into_new_context(void)
 
  printf("GTKWAVE | ...waveform reloaded\n");
  gtkwavetcl_setvar(WAVE_TCLCB_RELOAD_END, GLOBALS->loaded_file_name, WAVE_TCLCB_RELOAD_END_FLAGS);
+
+ /* update lower signal set in SST to correct position */
+#if WAVE_USE_GTK2
+   if((GLOBALS->dnd_sigview) && ((treeview_vadj_value != 0.0) || (treeview_hadj_value != 0.0)))
+	{
+	   struct Global *G2 = GLOBALS;
+	   while (gtk_events_pending()) gtk_main_iteration();
+
+	   if((G2 == GLOBALS)&&(GLOBALS->dnd_sigview))
+		{
+		   if(treeview_vadj_value != 0.0)
+			{
+			GtkAdjustment *vadj = gtk_tree_view_get_vadjustment((GtkTreeView *)GLOBALS->dnd_sigview);
+		
+			if((vadj) && (treeview_vadj_value >= vadj->lower) && (treeview_vadj_value <= vadj->upper))
+				{ 
+				vadj->value = treeview_vadj_value;
+				gtk_tree_view_set_vadjustment((GtkTreeView *)GLOBALS->dnd_sigview, vadj);
+		
+				gtk_signal_emit_by_name (GTK_OBJECT (GTK_ADJUSTMENT(vadj)), "changed");
+				gtk_signal_emit_by_name (GTK_OBJECT (GTK_ADJUSTMENT(vadj)), "value_changed"); 
+				}
+			}
+	
+		   if(treeview_hadj_value != 0.0)
+			{
+			GtkAdjustment *hadj = gtk_tree_view_get_hadjustment((GtkTreeView *)GLOBALS->dnd_sigview);
+		
+			if((hadj) && (treeview_hadj_value >= hadj->lower) && (treeview_hadj_value <= hadj->upper))
+				{ 
+				hadj->value = treeview_hadj_value;
+				gtk_tree_view_set_hadjustment((GtkTreeView *)GLOBALS->dnd_sigview, hadj);
+		
+				gtk_signal_emit_by_name (GTK_OBJECT (GTK_ADJUSTMENT(hadj)), "changed");
+				gtk_signal_emit_by_name (GTK_OBJECT (GTK_ADJUSTMENT(hadj)), "value_changed"); 
+				}
+			}
+		}
+	}
+#endif
 }
 
 
