@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2010.
+ * Copyright (c) Kermin Elliott Fleming 2007-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -268,6 +268,7 @@ char use_pango_fonts;
  */
 void *fst_fst_c_1; 
 const char *fst_scope_name;
+int fst_scope_name_len;
 TimeType first_cycle_fst_c_3;
 TimeType last_cycle_fst_c_3; 
 TimeType total_cycles_fst_c_3;
@@ -321,6 +322,19 @@ GtkTextTag *bold_tag_help_c_1; /* from help.c 118 */
 GtkWidget *window_help_c_2; /* from help.c 119 */
 
 
+/*
+ * hierpack.c
+ */
+unsigned char *hp_buf;
+size_t *hp_offs;
+size_t hp_prev;
+size_t hp_buf_siz;
+unsigned char *fmem_buf;
+size_t fmem_buf_siz;
+size_t fmem_buf_offs;
+size_t fmem_uncompressed_siz;
+
+
 /*
  * hiersearch.c
  */
@@ -873,6 +887,22 @@ char alt_hier_delimeter; /* from tree.c 479 */
 int fast_tree_sort; /* from tree.c 480 */
 struct symbol **facs2_tree_c_1; /* from tree.c 481 */
 int facs2_pos_tree_c_1; /* from tree.c 482 */
+unsigned char *talloc_pool_base;
+size_t talloc_idx;
+
+
+/*
+ * tree_component.c
+ */
+#ifdef _WAVE_HAVE_JUDY
+Pvoid_t comp_name_judy;
+#else
+JRB comp_name_jrb;
+#endif
+char **comp_name_idx;
+int comp_name_serial;
+size_t comp_name_total_stringmem;
+int comp_name_longest;
 
 
 /*
@@ -928,6 +958,7 @@ Traces tcache_treesearch_gtk2_c_2; /* from treesearch_gtk2.c 500 */
 unsigned char dnd_tgt_on_signalarea_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 501 */
 unsigned char dnd_tgt_on_wavearea_treesearch_gtk2_c_1; /* from treesearch_gtk2.c */
 GtkWidget *dnd_sigview; /* from treesearch_gtk2.c */
+GtkPaned *sst_vpaned; /* from treesearch_gtk2.c */
 
 
 /*
@@ -948,12 +979,6 @@ GtkWidget *clist_ttranslate_c_2;
  * vcd.c
  */
 unsigned char do_hier_compress; /* from vcd.c */
-JRB hier_pfx; /* from vcd.c */
-unsigned int hier_pfx_cnt; /* from vcd.c */
-char *prev_hier_pfx; /* from vcd.c */
-int prev_hier_pfx_len; /* from vcd.c */
-unsigned int prev_hier_pfx_cnt; /* from vcd.c */
-char **pfx_hier_array; /* from vcd.c */
 char *prev_hier_uncompressed_name; /* from vcd.c */
 jmp_buf *vcd_jmp_buf; /* from vcd.c */
 int vcd_warning_filesize; /* from vcd.c 502 */
