@@ -23,6 +23,12 @@
 #include <config.h>
 #include "lxt2_read.h"
 
+#if defined(USE_INLINE_ASM)
+#if defined(__i386__) || defined(__x86_64__)
+#define USE_X86_INLINE_ASM
+#endif
+#endif
+
 /****************************************************************************/
 
 #ifdef _WAVE_BE32
@@ -49,7 +55,7 @@
  * of a big-endian integer.  x86 specific version...
  */
 
-#if defined(__i386__) || defined(__x86_64__)
+#ifdef USE_X86_INLINE_ASM
 
 #define lxt2_rd_get_byte(mm,offset)		((unsigned int)(*((unsigned char *)(mm)+(offset))))
 
@@ -57,10 +63,10 @@ _LXT2_RD_INLINE static unsigned int lxt2_rd_get_16(void *mm, int offset)
 {
 unsigned short x = *((unsigned short *)((unsigned char *)mm+offset));
 
-#if defined(__i386__)
-    __asm("xchgb %b0,%h0" : "=q" (x) : "0" (x));
-#else
+#if defined(__x86_64__)
     __asm("xchgb %b0,%h0" : "=Q" (x) : "0" (x));
+#else
+    __asm("xchgb %b0,%h0" : "=q" (x) : "0" (x));
 #endif
 
     return (unsigned int) x;
@@ -1729,8 +1735,14 @@ return(blk);
 }
 
 /*
- * $Id: lxt2_read.c,v 1.4 2009/04/27 21:26:34 gtkwave Exp $
+ * $Id: lxt2_read.c,v 1.6 2010/10/25 17:56:49 gtkwave Exp $
  * $Log: lxt2_read.c,v $
+ * Revision 1.6  2010/10/25 17:56:49  gtkwave
+ * give x86_64 priority over 386 for inline assembly
+ *
+ * Revision 1.5  2010/10/25 17:50:42  gtkwave
+ * add conditional compiles for inline assembly code (can disable)
+ *
  * Revision 1.4  2009/04/27 21:26:34  gtkwave
  * printf format string warning fixes
  *
