@@ -579,6 +579,7 @@ while(!feof(f))
 
 		case 'b':
 			sp = strchr(buf, ' ');
+			if(!sp) break;
 			*sp = 0;
 			hash = vcdid_hash(sp+1, nl - (sp+1));
 			if(!hash_kill)
@@ -625,6 +626,7 @@ while(!feof(f))
 
 		case 's':
 			sp = strchr(buf, ' ');
+			if(!sp) break;
 			*sp = 0;
 			hash = vcdid_hash(sp+1, nl - (sp+1));
 			if(!hash_kill)
@@ -670,8 +672,11 @@ while(!feof(f))
 			*pnt = 0;
 			
 			sp = strchr(bin_fixbuff, ' ');
+			if(!sp) break;
 			sp = strchr(sp+1, ' ');
+			if(!sp) break;
 			sp = strchr(sp+1, ' ');
+			if(!sp) break;
 			*sp = 0;
 			hash = vcdid_hash(sp+1, nl - (sp+1));
 			if(!hash_kill)
@@ -694,6 +699,7 @@ while(!feof(f))
 
 		case 'r':
 			sp = strchr(buf, ' ');
+			if(!sp) break;
 			hash = vcdid_hash(sp+1, nl - (sp+1));
 			if(!hash_kill)
 				{
@@ -896,8 +902,11 @@ return(0);
 }
 
 /*
- * $Id: vcd2fst.c,v 1.20 2010/12/19 07:59:10 gtkwave Exp $
+ * $Id: vcd2fst.c,v 1.21 2010/12/27 19:40:16 gtkwave Exp $
  * $Log: vcd2fst.c,v $
+ * Revision 1.21  2010/12/27 19:40:16  gtkwave
+ * added null pointer checking during parsing of change records
+ *
  * Revision 1.20  2010/12/19 07:59:10  gtkwave
  * warnings fixes
  *
