@@ -117,24 +117,24 @@ static struct vcdsymbol **sorted=NULL;
 static struct vcdsymbol **indexed=NULL;
 
 enum VarTypes { V_EVENT, V_PARAMETER,
-                V_INTEGER, V_REAL, V_REAL_PARAMETER=V_REAL, V_REALTIME=V_REAL, V_REG, V_SUPPLY0,
+                V_INTEGER, V_REAL, V_REAL_PARAMETER=V_REAL, V_REALTIME=V_REAL, V_STRINGTYPE=V_REAL, V_REG, V_SUPPLY0,
                 V_SUPPLY1, V_TIME, V_TRI, V_TRIAND, V_TRIOR,
                 V_TRIREG, V_TRI0, V_TRI1, V_WAND, V_WIRE, V_WOR, V_PORT, V_IN=V_PORT, V_OUT=V_PORT, V_INOUT=V_PORT,
                 V_END, V_LB, V_COLON, V_RB, V_STRING };
 
 static char *vartypes[]={ "event", "parameter",
-                "integer", "real", "real_parameter", "realtime", "reg", "supply0",
+                "integer", "real", "real_parameter", "realtime", "string", "reg", "supply0",
                 "supply1", "time", "tri", "triand", "trior",
                 "trireg", "tri0", "tri1", "wand", "wire", "wor", "port", "in", "out", "inout",
                 "$end", "", "", "", ""};
 
 static const unsigned char varenums[] = {  V_EVENT, V_PARAMETER,
-                V_INTEGER, V_REAL, V_REAL_PARAMETER, V_REALTIME, V_REG, V_SUPPLY0,
+                V_INTEGER, V_REAL, V_REAL_PARAMETER, V_REALTIME, V_STRINGTYPE, V_REG, V_SUPPLY0,
                 V_SUPPLY1, V_TIME, V_TRI, V_TRIAND, V_TRIOR,
                 V_TRIREG, V_TRI0, V_TRI1, V_WAND, V_WIRE, V_WOR, V_PORT, V_IN, V_OUT, V_INOUT,
                 V_END, V_LB, V_COLON, V_RB, V_STRING };
 
-#define NUM_VTOKENS 24
+#define NUM_VTOKENS 25
 
 static int numsyms=0;
 
@@ -156,8 +156,8 @@ s+=(len-1);
 
 for(i=0;i<len;i++)
         {
-        val *= 95;                              /* was 94 but XL uses '!' as right hand side chars which act as leading zeros */
-        val += (((unsigned char)*s) - 32);      /* was 33 but XL ... */                                
+        val *= 94;
+        val += (((unsigned char)*s) - 32);
         s--;
         }
 
@@ -2010,8 +2010,14 @@ return(0);
 }
 
 /*
- * $Id: vcd2lxt2.c,v 1.12 2010/10/02 19:05:51 gtkwave Exp $
+ * $Id: vcd2lxt2.c,v 1.14 2010/12/14 19:53:14 gtkwave Exp $
  * $Log: vcd2lxt2.c,v $
+ * Revision 1.14  2010/12/14 19:53:14  gtkwave
+ * scaled back id multiplier from 95 to 94
+ *
+ * Revision 1.13  2010/12/12 18:32:45  gtkwave
+ * add "string" variable type to parsing of vcd variable declarations
+ *
  * Revision 1.12  2010/10/02 19:05:51  gtkwave
  * fix shadowed time variable
  *
