@@ -36,6 +36,12 @@
 #include <fcntl.h>
 #endif
 
+#if defined(USE_INLINE_ASM)
+#if defined(__i386__) || defined(__x86_64__)
+#define USE_X86_INLINE_ASM
+#endif
+#endif
+
 /****************************************************************************/
 
 struct vzt_ncycle_autosort
@@ -117,7 +123,7 @@ if(lt->pthreads)
  * of a big-endian integer.  x86 specific version...
  */
 
-#if defined(__i386__) || defined(__x86_64__)
+#ifdef USE_X86_INLINE_ASM
 
 #define vzt_rd_get_byte(mm,offset)		((unsigned int)(*((unsigned char *)(mm)+(offset))))
 
@@ -125,10 +131,10 @@ _VZT_RD_INLINE static unsigned int vzt_rd_get_16(void *mm, int offset)
 {
 unsigned short x = *((unsigned short *)((unsigned char *)mm+offset));
 
-#if defined(__i386__)
-    __asm("xchgb %b0,%h0" : "=q" (x) : "0" (x));
-#else
+#if defined(__x86_64__)
     __asm("xchgb %b0,%h0" : "=Q" (x) : "0" (x));
+#else
+    __asm("xchgb %b0,%h0" : "=q" (x) : "0" (x));
 #endif
 
     return (unsigned int) x;
@@ -2378,8 +2384,14 @@ return(rcval);
 }
 
 /*
- * $Id: vzt_read.c,v 1.8 2009/12/26 19:44:15 gtkwave Exp $
+ * $Id: vzt_read.c,v 1.10 2010/10/25 17:56:49 gtkwave Exp $
  * $Log: vzt_read.c,v $
+ * Revision 1.10  2010/10/25 17:56:49  gtkwave
+ * give x86_64 priority over 386 for inline assembly
+ *
+ * Revision 1.9  2010/10/25 17:50:42  gtkwave
+ * add conditional compiles for inline assembly code (can disable)
+ *
  * Revision 1.8  2009/12/26 19:44:15  gtkwave
  * warnings fixes
  *
