@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -65,19 +65,19 @@ if(!GLOBALS->hier_grouping)
 	                        strcpy(tmp+4, t2->name);
 	                        }
                         	else
-				if(t2->which!=-1)
+				if(t2->t_which >= 0)
 				{
-				if(GLOBALS->facs[t2->which]->vec_root)
+				if(GLOBALS->facs[t2->t_which]->vec_root)
 					{
 					if(GLOBALS->autocoalesce)
 						{
-						if(GLOBALS->facs[t2->which]->vec_root!=GLOBALS->facs[t2->which])
+						if(GLOBALS->facs[t2->t_which]->vec_root!=GLOBALS->facs[t2->t_which])
 							{
 							t2=t2->next;
 							continue;
 							}
 
-						tmp2=makename_chain(GLOBALS->facs[t2->which]);
+						tmp2=makename_chain(GLOBALS->facs[t2->t_which]);
 						tmp3=leastsig_hiername(tmp2);
 						tmp=wave_alloca(strlen(tmp3)+4);
 						strcpy(tmp,   "[] ");
@@ -98,7 +98,8 @@ if(!GLOBALS->hier_grouping)
 				}
 				else
 	                        {
-	                        tmp=t2->name;
+	                        /* tmp=t2->name; */
+				goto skip_node; /* GHW */
 	                        }
 			row=gtk_clist_prepend(cl,(gchar **)&tmp);
 			pixlen=font_engine_string_measure(GLOBALS->signalfont,(gchar *)(tmp));
@@ -106,7 +107,7 @@ if(!GLOBALS->hier_grouping)
 		maxpixlen=(pixlen>maxpixlen)?pixlen:maxpixlen;		
 		gtk_clist_set_row_data(cl, row,t2); 
 		GLOBALS->num_rows_hiersearch_c_1++;
-		t2=t2->next;
+skip_node:	t2=t2->next;
 		}
 	}
 	else
@@ -118,19 +119,19 @@ if(!GLOBALS->hier_grouping)
 		{
                 if(!t2->child)
                         {
-			if(t2->which!=-1)
+			if(t2->t_which >= 0)
 				{
-				if(GLOBALS->facs[t2->which]->vec_root)
+				if(GLOBALS->facs[t2->t_which]->vec_root)
 					{
 					if(GLOBALS->autocoalesce)
 						{
-						if(GLOBALS->facs[t2->which]->vec_root!=GLOBALS->facs[t2->which])
+						if(GLOBALS->facs[t2->t_which]->vec_root!=GLOBALS->facs[t2->t_which])
 							{
 							t2=t2->next;
 							continue;
 							}
 
-						tmp2=makename_chain(GLOBALS->facs[t2->which]);
+						tmp2=makename_chain(GLOBALS->facs[t2->t_which]);
 						tmp3=leastsig_hiername(tmp2);
 						tmp=wave_alloca(strlen(tmp3)+4);
 						strcpy(tmp,   "[] ");
@@ -151,7 +152,8 @@ if(!GLOBALS->hier_grouping)
 				}
 				else
 	                        {
-	                        tmp=t2->name;
+	                        /* tmp=t2->name; */
+				goto skip_node_2; /* GHW */
 	                        }
 
 			row=gtk_clist_prepend(cl,(gchar **)&tmp);
@@ -160,7 +162,7 @@ if(!GLOBALS->hier_grouping)
 			gtk_clist_set_row_data(cl, row,t2); 
 			GLOBALS->num_rows_hiersearch_c_1++;
                         }
-		t2=t2->next;
+skip_node_2:	t2=t2->next;
 		}
 
 	t2=t;
@@ -310,9 +312,10 @@ if(!GLOBALS->h_selectedtree_hiersearch_c_1) return;
 
 set_window_busy(widget);
 
-for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i++)
         {
         struct symbol *s;  
+	if(i<0) break; /* GHW */
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
@@ -325,9 +328,10 @@ if(GLOBALS->is_lx2)
 	{
 	int pre_import = 0;
 
-	for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
+	for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i++)
 	        {
 	        struct symbol *s, *t;  
+		if(i<0) break; /* GHW */
 	        s=GLOBALS->facs[i];
 		t=s->vec_root;
 		if((t)&&(GLOBALS->autocoalesce))
@@ -362,10 +366,11 @@ if(GLOBALS->is_lx2)
 	}
 /* LX2 */
 
-for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i++)
         {
 	int len;
         struct symbol *s, *t;  
+	if(i<0) break; /* GHW */
         s=GLOBALS->facs[i];
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
@@ -410,9 +415,10 @@ GLOBALS->traces.first=GLOBALS->traces.last=NULL;
 
 set_window_busy(widget);
 
-for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i++)
         {
         struct symbol *s;  
+	if(i<0) break; /* GHW */
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
@@ -425,9 +431,10 @@ if(GLOBALS->is_lx2)
 	{
 	int pre_import = 0;
 
-	for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
+	for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i++)
 	        {
 	        struct symbol *s, *t;  
+		if(i<0) break; /* GHW */
 	        s=GLOBALS->facs[i];
 		t=s->vec_root;
 		if((t)&&(GLOBALS->autocoalesce))
@@ -462,10 +469,11 @@ if(GLOBALS->is_lx2)
 	}
 /* LX2 */
 
-for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i++)
         {
 	int len;
         struct symbol *s, *t;  
+	if(i<0) break; /* GHW */
         s=GLOBALS->facs[i];
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
@@ -523,9 +531,10 @@ GLOBALS->traces.first=GLOBALS->traces.last=NULL;
 
 set_window_busy(widget);
 
-for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i++)
         {
         struct symbol *s;  
+	if(i<0) break; /* GHW */
         s=GLOBALS->facs[i];
 	if(s->vec_root)
 		{
@@ -538,9 +547,10 @@ if(GLOBALS->is_lx2)
 	{
 	int pre_import = 0;
 
-	for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
+	for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i++)
 	        {
 	        struct symbol *s, *t;  
+		if(i<0) break; /* GHW */
 	        s=GLOBALS->facs[i];
 		t=s->vec_root;
 		if((t)&&(GLOBALS->autocoalesce))
@@ -575,10 +585,11 @@ if(GLOBALS->is_lx2)
 	}
 /* LX2 */
 
-for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i++)
+for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i<=fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which;i++)
         {
 	int len;
         struct symbol *s, *t;  
+	if(i<0) break; /* GHW */
         s=GLOBALS->facs[i];
 	t=s->vec_root;
 	if((t)&&(GLOBALS->autocoalesce))
@@ -659,8 +670,8 @@ if(GLOBALS->entrybox_text_local_hiersearch_c_1)
 	
 	        DEBUG(printf("Bundle name is: %s\n",entrybox_text_local));
 	        add_vector_range(GLOBALS->entrybox_text_local_hiersearch_c_1,
-	                        fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which,
-	                        fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->which,
+	                        fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which,
+	                        fetchhigh(GLOBALS->h_selectedtree_hiersearch_c_1)->t_which,
 	                        GLOBALS->bundle_direction_hiersearch_c_1);
 		}
         free_2(GLOBALS->entrybox_text_local_hiersearch_c_1);
@@ -979,8 +990,11 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 }
 
 /*
- * $Id: hiersearch.c,v 1.9 2010/05/27 06:07:24 gtkwave Exp $
+ * $Id: hiersearch.c,v 1.10 2011/01/17 19:24:21 gtkwave Exp $
  * $Log: hiersearch.c,v $
+ * Revision 1.10  2011/01/17 19:24:21  gtkwave
+ * tree modifications to support decorated internal hierarchy nodes
+ *
  * Revision 1.9  2010/05/27 06:07:24  gtkwave
  * Moved gtk_grab_add() after gtk_widget_show() as newer gtk needs that order.
  *
