@@ -139,7 +139,7 @@ JRB make_jrb()
   return head;
 }
  
-JRB jrb_find_gte_str(JRB n, char *key, int *fnd)
+JRB jrb_find_gte_str(JRB n, const char *key, int *fnd)
 {
   int cmp;
  
@@ -167,7 +167,7 @@ JRB jrb_find_gte_str(JRB n, char *key, int *fnd)
   }
 }
  
-JRB jrb_find_str(JRB n, char *key)
+JRB jrb_find_str(JRB n, const char *key)
 {
   int fnd;
   JRB j;
@@ -607,8 +607,11 @@ JRB jrb_insert_gen(JRB tree, Jval key, Jval val,
 }
 
 /*
- * $Id: jrb.c,v 1.3 2009/12/24 20:55:27 gtkwave Exp $
+ * $Id: jrb.c,v 1.4 2011/01/18 03:06:28 gtkwave Exp $
  * $Log: jrb.c,v $
+ * Revision 1.4  2011/01/18 03:06:28  gtkwave
+ * added JRB support for component trees when Judy is not available
+ *
  * Revision 1.3  2009/12/24 20:55:27  gtkwave
  * warnings cleanups
  *
