@@ -23,6 +23,11 @@
 
 enum LXT2_Loader_Type_Encodings { LXT2_IS_INACTIVE, LXT2_IS_LXT2, LXT2_IS_VZT, LXT2_IS_AET2, LXT2_IS_VLIST, LXT2_IS_FST };
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(push)
+#pragma pack(1)
+#endif
+
 struct lx2_entry
 {
 struct HistEnt *histent_head, *histent_curr;
@@ -30,6 +35,11 @@ int numtrans;
 nptr np;
 };
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(pop)
+#endif
+
+
 TimeType lx2_main(char *fname, char *skip_start, char *skip_end);
 void import_lx2_trace(nptr np);
 
@@ -39,8 +49,11 @@ void lx2_import_masked(void);
 #endif
 
 /*
- * $Id: lx2.h,v 1.5 2010/09/15 18:35:42 gtkwave Exp $
+ * $Id: lx2.h,v 1.6 2010/12/17 06:29:20 gtkwave Exp $
  * $Log: lx2.h,v $
+ * Revision 1.6  2010/12/17 06:29:20  gtkwave
+ * Added --enable-struct-pack configure flag
+ *
  * Revision 1.5  2010/09/15 18:35:42  gtkwave
  * added F_NAME_MODULUS to reduce temp memory usage
  *
