@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2001-2010.
+ * Copyright (c) Tony Bybell 2001-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -434,7 +434,7 @@ fprintf(stderr, LXTHDR"...expanded %d entries from %08x into %08x bytes.\n", GLO
 /*
  * decompress facility names and build up fac geometry
  */
-static void build_facs(char *fname, char **f_name)
+static void build_facs(char *fname, char **f_name, struct Node *node_block)
 {
 char *buf, *bufprev = NULL, *bufcurr;
 off_t offs=GLOBALS->facname_offset_lxt_c_1+8;
@@ -448,11 +448,8 @@ char *decmem=NULL;
 FILE *tmp;
 #endif
 
-if(!GLOBALS->do_hier_compress)
-	{
-	buf=malloc_2(total_mem);
-	pnt=bufprev=buf;
-	}
+buf=malloc_2(total_mem);
+pnt=bufprev=buf;
 
 if(GLOBALS->zfacname_size_lxt_c_1)
 	{
@@ -478,52 +475,20 @@ if(GLOBALS->zfacname_size_lxt_c_1)
 	offs=0;	/* we're in our new memory region now.. */
 	}
 
-if(GLOBALS->do_hier_compress)
+fprintf(stderr, LXTHDR"Building %d facilities.\n", GLOBALS->numfacs);
+for(i=0;i<GLOBALS->numfacs;i++)
 	{
-	char workspace[4097];
-	int was_packed;
-	char *string_ret;
-
-	workspace[0] = 0;
-
-	fprintf(stderr, LXTHDR"Building %d compressed facilities.\n", GLOBALS->numfacs);
-	for(i=0;i<GLOBALS->numfacs;i++)
+        clone=get_16(offs);  offs+=2;
+	bufcurr=pnt;
+	for(j=0;j<clone;j++)
 		{
-	        clone=get_16(offs);  offs+=2;
-		pnt=workspace+clone;
-	        while((*(pnt++)=get_byte(offs++)));
-		string_ret =  hier_compress(workspace, HIERPACK_ADD, &was_packed);
-		if(was_packed)
-			{
-			f_name[i]=string_ret;
-			}
-			else
-			{
-		        f_name[i]=strdup_2(workspace);
-			}
-	        }
-	}
-	else
-	{
-	fprintf(stderr, LXTHDR"Building %d facilities.\n", GLOBALS->numfacs);
-	for(i=0;i<GLOBALS->numfacs;i++)
-		{
-	        clone=get_16(offs);  offs+=2;
-		bufcurr=pnt;
-		for(j=0;j<clone;j++)
-			{
-			*(pnt++) = *(bufprev++);
-			}
-	        while((*(pnt++)=get_byte(offs++)));
-	        f_name[i]=bufcurr;
-		DEBUG(printf(LXTHDR"Encountered facility %d: '%s'\n", i, bufcurr));
-		bufprev=bufcurr;
-	        }
-	}
-
-create_hier_array();
-
-if(GLOBALS->prev_hier_uncompressed_name) { free_2(GLOBALS->prev_hier_uncompressed_name); GLOBALS->prev_hier_uncompressed_name = NULL; }
+		*(pnt++) = *(bufprev++);
+		}
+        while((*(pnt++)=get_byte(offs++)));
+        f_name[i]=bufcurr;
+	DEBUG(printf(LXTHDR"Encountered facility %d: '%s'\n", i, bufcurr));
+	bufprev=bufcurr;
+        }
 
 if(GLOBALS->zfacname_size_lxt_c_1)
 	{
@@ -570,14 +535,14 @@ if(GLOBALS->zfacgeometry_size_lxt_c_1)
 
 for(i=0;i<GLOBALS->numfacs;i++)
 	{
-	GLOBALS->mvlfacs_lxt_c_2[i].array_height=get_32(offs);
-	GLOBALS->mvlfacs_lxt_c_2[i].msb=get_32(offs+4);
-	GLOBALS->mvlfacs_lxt_c_2[i].lsb=get_32(offs+8);
+	GLOBALS->mvlfacs_lxt_c_2[i].node_alias=get_32(offs);
+	node_block[i].msi=get_32(offs+4);
+	node_block[i].lsi=get_32(offs+8);
 	GLOBALS->mvlfacs_lxt_c_2[i].flags=get_32(offs+12);
-	GLOBALS->mvlfacs_lxt_c_2[i].len=(GLOBALS->mvlfacs_lxt_c_2[i].lsb>GLOBALS->mvlfacs_lxt_c_2[i].msb)?(GLOBALS->mvlfacs_lxt_c_2[i].lsb-GLOBALS->mvlfacs_lxt_c_2[i].msb+1):(GLOBALS->mvlfacs_lxt_c_2[i].msb-GLOBALS->mvlfacs_lxt_c_2[i].lsb+1);
+	GLOBALS->mvlfacs_lxt_c_2[i].len=(node_block[i].lsi>node_block[i].msi)?(node_block[i].lsi-node_block[i].msi+1):(node_block[i].msi-node_block[i].lsi+1);
 
 	if(GLOBALS->mvlfacs_lxt_c_2[i].len>GLOBALS->lt_len_lxt_c_1) GLOBALS->lt_len_lxt_c_1 = GLOBALS->mvlfacs_lxt_c_2[i].len;
-	DEBUG(printf(LXTHDR"%s[%d:%d]\n", mvlfacs[i].f_name, mvlfacs[i].msb, mvlfacs[i].lsb));
+	DEBUG(printf(LXTHDR"%s[%d:%d]\n", mvlfacs[i].f_name, node_block[i].msi, node_block[i].lsi));
 
 	offs+=0x10;
 	}
@@ -1087,7 +1052,7 @@ if(!GLOBALS->sync_table_offset_lxt_c_1)
 
 		offscache2 = offs;
 
-		height = GLOBALS->mvlfacs_lxt_c_2[facidx].array_height;
+		height = GLOBALS->mvlfacs_lxt_c_2[facidx].node_alias;
 		if(height)
 			{
 			if(height >= 256*65536)       
@@ -1607,7 +1572,10 @@ if(GLOBALS->zdictionary_offset_lxt_c_1)
 		}
 	}
 
-build_facs(fname, f_name);
+sym_block = (struct symbol *)calloc_2(GLOBALS->numfacs, sizeof(struct symbol));
+node_block = (struct Node *)calloc_2(GLOBALS->numfacs,sizeof(struct Node));
+
+build_facs(fname, f_name, node_block);
 /* SPLASH */                            splash_sync(1, 5);
 build_facs2(fname);
 /* SPLASH */                            splash_sync(2, 5);
@@ -1619,9 +1587,6 @@ if(!GLOBALS->hier_was_explicitly_set)    /* set default hierarchy split char */
         GLOBALS->hier_delimeter='.';
         }
 
-sym_block = (struct symbol *)calloc_2(GLOBALS->numfacs, sizeof(struct symbol));
-node_block = (struct Node *)calloc_2(GLOBALS->numfacs,sizeof(struct Node));
-
 for(i=0;i<GLOBALS->numfacs;i++)
         {
 	char buf[4096];
@@ -1630,12 +1595,12 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	if(GLOBALS->mvlfacs_lxt_c_2[i].flags&LT_SYM_F_ALIAS)
 		{
-		int alias = GLOBALS->mvlfacs_lxt_c_2[i].array_height;
+		int alias = GLOBALS->mvlfacs_lxt_c_2[i].node_alias;
 		f=GLOBALS->mvlfacs_lxt_c_2+alias;
 
 		while(f->flags&LT_SYM_F_ALIAS)
 			{
-			f=GLOBALS->mvlfacs_lxt_c_2+f->array_height;
+			f=GLOBALS->mvlfacs_lxt_c_2+f->node_alias;
 			}
 		}
 		else
@@ -1645,7 +1610,7 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	if((f->len>1)&& (!(f->flags&(LT_SYM_F_INTEGER|LT_SYM_F_DOUBLE|LT_SYM_F_STRING))) )
 		{
-		int len = sprintf(buf, "%s[%d:%d]", f_name[i],GLOBALS->mvlfacs_lxt_c_2[i].msb, GLOBALS->mvlfacs_lxt_c_2[i].lsb);
+		int len = sprintf(buf, "%s[%d:%d]", f_name[i],node_block[i].msi, node_block[i].lsi);
 		str=malloc_2(len+1);
 		if(!GLOBALS->alt_hier_delimeter)
 			{
@@ -1659,58 +1624,58 @@ for(i=0;i<GLOBALS->numfacs;i++)
                 symadd_name_exists_sym_exists(s,str,0);
 		prevsymroot = prevsym = NULL;
 		}
-	else if ( 
-			((f->len==1)&&(!(f->flags&(LT_SYM_F_INTEGER|LT_SYM_F_DOUBLE|LT_SYM_F_STRING)))&&
-			((i!=GLOBALS->numfacs-1)&&(!strcmp(f_name[i], f_name[i+1]))))
-			||
-			(((i!=0)&&(!strcmp(f_name[i], f_name[i-1]))) &&
-			(GLOBALS->mvlfacs_lxt_c_2[i].msb!=-1)&&(GLOBALS->mvlfacs_lxt_c_2[i].lsb!=-1))
-		)
-		{
-		int len = sprintf(buf, "%s[%d]", f_name[i],GLOBALS->mvlfacs_lxt_c_2[i].msb);
-		str=malloc_2(len+1);
-		if(!GLOBALS->alt_hier_delimeter)
-			{
-			strcpy(str, buf);
-			}
-			else
-			{
-			strcpy_vcdalt(str, buf, GLOBALS->alt_hier_delimeter);
-			}
-                s=&sym_block[i];
-                symadd_name_exists_sym_exists(s,str,0);
-		if((prevsym)&&(i>0)&&(!strcmp(f_name[i], f_name[i-1]))&&(!strchr(f_name[i], '\\'))) /* allow chaining for search functions.. */
-			{
-			prevsym->vec_root = prevsymroot;
-			prevsym->vec_chain = s;
-			s->vec_root = prevsymroot;
-			prevsym = s;
-			}
-			else
-			{
-			prevsymroot = prevsym = s;
-			}
-		}
 		else
 		{
-		str=malloc_2(strlen(f_name[i])+1);
-		if(!GLOBALS->alt_hier_delimeter)
+		int gatecmp = (f->len==1) && (!(f->flags&(LT_SYM_F_INTEGER|LT_SYM_F_DOUBLE|LT_SYM_F_STRING))) && (node_block[i].msi!=-1) && (node_block[i].lsi!=-1);
+		int revcmp = gatecmp && (i) && (!strcmp(f_name[i], f_name[i-1]));
+
+		if(gatecmp)
 			{
-			strcpy(str, f_name[i]);
+			int len = sprintf(buf, "%s[%d]", f_name[i],node_block[i].msi);
+			str=malloc_2(len+1);
+			if(!GLOBALS->alt_hier_delimeter)
+				{
+				strcpy(str, buf);
+				}
+				else
+				{
+				strcpy_vcdalt(str, buf, GLOBALS->alt_hier_delimeter);
+				}
+	                s=&sym_block[i];
+	                symadd_name_exists_sym_exists(s,str,0);
+			if((prevsym)&&(revcmp)&&(!strchr(f_name[i], '\\'))) /* allow chaining for search functions.. */
+				{
+				prevsym->vec_root = prevsymroot;
+				prevsym->vec_chain = s;
+				s->vec_root = prevsymroot;
+				prevsym = s;
+				}
+				else
+				{
+				prevsymroot = prevsym = s;
+				}
 			}
 			else
 			{
-			strcpy_vcdalt(str, f_name[i], GLOBALS->alt_hier_delimeter);
-			}
-                s=&sym_block[i];
-                symadd_name_exists_sym_exists(s,str,0);
-		prevsymroot = prevsym = NULL;
-
-		if(f->flags&LT_SYM_F_INTEGER)
-			{
-			GLOBALS->mvlfacs_lxt_c_2[i].msb=31;
-			GLOBALS->mvlfacs_lxt_c_2[i].lsb=0;
-			GLOBALS->mvlfacs_lxt_c_2[i].len=32;
+			str=malloc_2(strlen(f_name[i])+1);
+			if(!GLOBALS->alt_hier_delimeter)
+				{
+				strcpy(str, f_name[i]);
+				}
+				else
+				{
+				strcpy_vcdalt(str, f_name[i], GLOBALS->alt_hier_delimeter);
+				}
+	                s=&sym_block[i];
+	                symadd_name_exists_sym_exists(s,str,0);
+			prevsymroot = prevsym = NULL;
+	
+			if(f->flags&LT_SYM_F_INTEGER)
+				{
+				node_block[i].msi=31;
+				node_block[i].lsi=0;
+				GLOBALS->mvlfacs_lxt_c_2[i].len=32;
+				}
 			}
 		}
 		
@@ -1720,8 +1685,6 @@ for(i=0;i<GLOBALS->numfacs;i++)
 
 	if((f->len>1)||(f->flags&(LT_SYM_F_DOUBLE|LT_SYM_F_STRING)))
 		{
-		n->msi = GLOBALS->mvlfacs_lxt_c_2[i].msb;
-		n->lsi = GLOBALS->mvlfacs_lxt_c_2[i].lsb;
 		n->extvals = 1;
 		}
 
@@ -1789,18 +1752,7 @@ init_tree();
 for(i=0;i<GLOBALS->numfacs;i++)	
 {
 char *nf = GLOBALS->facs[i]->name;
-int was_packed;
-char *recon = hier_decompress_flagged(nf, &was_packed);
-
-if(was_packed)
-        {
-        build_tree_from_name(recon, i);   
-        free_2(recon);
-        }
-        else
-        {
-        build_tree_from_name(nf, i);
-        }
+build_tree_from_name(nf, i);
 }
 /* SPLASH */                            splash_sync(5, 5);
 
@@ -1894,7 +1846,7 @@ if(!(f=np->mv.mvlfac)) return;	/* already imported */
 
 if(np->mv.mvlfac->flags&LT_SYM_F_ALIAS)
 	{
-	int alias = np->mv.mvlfac->array_height;
+	int alias = np->mv.mvlfac->node_alias;
 	f=GLOBALS->mvlfacs_lxt_c_2+alias;
 
 	if(GLOBALS->resolve_lxt_alias_to[alias])
@@ -1908,15 +1860,15 @@ if(np->mv.mvlfac->flags&LT_SYM_F_ALIAS)
 
 	while(f->flags&LT_SYM_F_ALIAS)
 		{
-		f=GLOBALS->mvlfacs_lxt_c_2+f->array_height;
+		f=GLOBALS->mvlfacs_lxt_c_2+f->node_alias;
 
-		if(GLOBALS->resolve_lxt_alias_to[f->array_height])
+		if(GLOBALS->resolve_lxt_alias_to[f->node_alias])
 			{
-			if(!GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2]) GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2] = GLOBALS->resolve_lxt_alias_to[f->array_height];
+			if(!GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2]) GLOBALS->resolve_lxt_alias_to[np->mv.mvlfac - GLOBALS->mvlfacs_lxt_c_2] = GLOBALS->resolve_lxt_alias_to[f->node_alias];
 			}
 			else
 			{
-			GLOBALS->resolve_lxt_alias_to[f->array_height] = np; 
+			GLOBALS->resolve_lxt_alias_to[f->node_alias] = np; 
 			}
 		}
 	}
@@ -1962,7 +1914,7 @@ histent_head->next = htemp;	/* x */
 
 np->numhist=2;
 
-if(f->array_height < 1)	/* sorry, arrays not supported */
+if(f->node_alias < 1)	/* sorry, arrays not supported */
 while(offs)
 	{
 	unsigned char val = 0;
@@ -2283,13 +2235,23 @@ while(offs)
 
 			if(GLOBALS->double_is_native_lxt_c_1)
 				{
+#ifdef WAVE_HAS_H_DOUBLE
+				memcpy(&htemp->v.h_double, ((char *)GLOBALS->mm_lxt_c_1+offs_dbl), sizeof(double));
+#else
 				htemp->v.h_vector = ((char *)GLOBALS->mm_lxt_c_1+offs_dbl);
 				DEBUG(printf(LXTHDR"Added double '%.16g'\n", *((double *)(GLOBALS->mm_lxt_c_1+offs_dbl))));
+#endif
 				}
 				else
 				{
+#ifdef WAVE_HAS_H_DOUBLE
+				double *h_d = (double *)swab_double_via_mask(offs_dbl);
+				htemp->v.h_double = *h_d;
+				free_2(h_d);
+#else
 				htemp->v.h_vector = swab_double_via_mask(offs_dbl);
 				DEBUG(printf(LXTHDR"Added bytefixed double '%.16g'\n", *((double *)(htemp->v.h_vector))));
+#endif
 				}
 			htemp->time = tmval;
 			htemp->next = histent_head;
@@ -2415,8 +2377,17 @@ np->numhist++;
 }
 
 /*
- * $Id: lxt.c,v 1.21 2010/12/06 18:53:55 gtkwave Exp $
+ * $Id: lxt.c,v 1.24 2011/01/21 15:49:52 gtkwave Exp $
  * $Log: lxt.c,v $
+ * Revision 1.24  2011/01/21 15:49:52  gtkwave
+ * simplify strand coalesce routine and make same as FST's
+ *
+ * Revision 1.23  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
+ * Revision 1.22  2011/01/07 20:17:10  gtkwave
+ * remove redundant fields from struct fac
+ *
  * Revision 1.21  2010/12/06 18:53:55  gtkwave
  * __asm directive error fix for AMD64
  *
