@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2010.
+ * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1305,6 +1305,11 @@ load_vcd:
 	}
 
 
+if((GLOBALS->loaded_file_type != FST_FILE) || (!GLOBALS->fast_tree_sort))
+	{
+	GLOBALS->do_hier_compress = 0; /* for now, add more file formats in the future */
+	}
+
 /* deallocate the symbol hash table */
 sym_hash_destroy(GLOBALS);
 
@@ -2711,8 +2716,11 @@ void optimize_vcd_file(void) {
 #endif
 
 /*
- * $Id: main.c,v 1.103 2010/11/07 16:20:33 gtkwave Exp $
+ * $Id: main.c,v 1.104 2011/01/13 17:20:39 gtkwave Exp $
  * $Log: main.c,v $
+ * Revision 1.104  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
  * Revision 1.103  2010/11/07 16:20:33  gtkwave
  * make fst the default file format for --optimize action in gtkwave
  *
