@@ -45,9 +45,7 @@ char *name;
 
 
 enum WV_MenuItems {
-#if !defined __MINGW32__ && !defined _MSC_VER
 WV_MENU_FONV,
-#endif
 WV_MENU_FONVT,
 WV_MENU_FRW,
 WV_MENU_WRVCD,
@@ -106,12 +104,10 @@ WV_MENU_EDFRON,
 WV_MENU_EDFROFF,
 WV_MENU_XLF_0,
 WV_MENU_XLF_1,
-#if !defined __MINGW32__ && !defined _MSC_VER
 WV_MENU_XLP_0,
 WV_MENU_XLP_1,
 WV_MENU_TTXLP_0,
 WV_MENU_TTXLP_1,
-#endif
 WV_MENU_EDFAOFF,
 WV_MENU_EDFASTEP,
 WV_MENU_EDFAINTERPOL,
@@ -337,12 +333,14 @@ GtkItemFactoryEntry *retrieve_menu_items_array(int *num_items);
 
 void menu_read_stems_cleanup(GtkWidget *widget, gpointer data);
 void menu_new_viewer_tab_cleanup(GtkWidget *widget, gpointer data);
+int menu_new_viewer_tab_cleanup_2(char *fname);
+
 
 void set_scale_to_time_dimension_toggles(void);
 
 /* These should eventually have error values */
 void write_save_helper(FILE *file);
-void read_save_helper(char *wname);
+int read_save_helper(char *wname); /* -1 = error, 0+ = number of lines read */
 
 void SetTraceScrollbarRowValue(int row, unsigned center);
 
@@ -351,8 +349,20 @@ bvptr combine_traces(int direction, Trptr single_trace_only);
 #endif
 
 /*
- * $Id: menu.h,v 1.40 2010/07/12 20:51:42 gtkwave Exp $
+ * $Id: menu.h,v 1.44 2010/10/06 20:15:51 gtkwave Exp $
  * $Log: menu.h,v $
+ * Revision 1.44  2010/10/06 20:15:51  gtkwave
+ * preliminary version of RPC mechanism
+ *
+ * Revision 1.43  2010/08/26 18:42:23  gtkwave
+ * added support for transaction filters in mingw
+ *
+ * Revision 1.42  2010/08/26 01:32:01  gtkwave
+ * added mingw support for Open New Window menu option
+ *
+ * Revision 1.41  2010/08/25 22:58:23  gtkwave
+ * added process file support for mingw
+ *
  * Revision 1.40  2010/07/12 20:51:42  gtkwave
  * free to non-malloc'd address fix
  *
