@@ -145,7 +145,11 @@ if(t->name)
 						{
 						if(!(h_ptr->flags&HIST_STRING))
 							{
+#ifdef WAVE_HAS_H_DOUBLE
+							str=convert_ascii_real(t, &h_ptr->v.h_double);
+#else
 							str=convert_ascii_real(t, (double *)h_ptr->v.h_vector);
+#endif
 							}
 							else
 							{
