@@ -41,7 +41,7 @@ if(!(t->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
 		{
 		if(!HasAlias(t))
 			{
-			int flagged;
+			int flagged = 0;
 	                s = hier_decompress_flagged(t->n.nd->nname, &flagged);
 			if(!flagged) s = strdup_2(s);
 			}
@@ -189,7 +189,11 @@ if(tname)
 						{
 						if(!(h_ptr->flags&HIST_STRING))
 							{
+#ifdef WAVE_HAS_H_DOUBLE
+							str=convert_ascii_real(t, &h_ptr->v.h_double);
+#else
 							str=convert_ascii_real(t, (double *)h_ptr->v.h_vector);
+#endif
 							}
 							else
 							{
@@ -446,8 +450,11 @@ if(tname) { free_2(tname); }
 }
 
 /*
- * $Id: mouseover_sigs.c,v 1.10 2010/04/04 19:09:57 gtkwave Exp $
+ * $Id: mouseover_sigs.c,v 1.11 2011/01/13 17:20:39 gtkwave Exp $
  * $Log: mouseover_sigs.c,v $
+ * Revision 1.11  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
  * Revision 1.10  2010/04/04 19:09:57  gtkwave
  * rename name->bvname in struct BitVector for easier grep tracking
  *
