@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2010. 
+ * Copyright (c) Tony Bybell 1999-2011. 
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free
@@ -773,9 +773,14 @@ ps_MaxSignalLength (void)
 			    {
 			      if (!(h_ptr->flags & HIST_STRING))
 				{
+#ifdef WAVE_HAS_H_DOUBLE
+				  str =
+				    convert_ascii_real (t, &h_ptr->v.h_double);
+#else
 				  str =
 				    convert_ascii_real (t, (double *) h_ptr->v.
 							h_vector);
+#endif
 				}
 			      else
 				{
@@ -1527,8 +1532,12 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
 		  tv = mynan;
 		  if (h3->flags & HIST_REAL)
 		    {
+#ifdef WAVE_HAS_H_DOUBLE
+		      if (!(h3->flags & HIST_STRING)) tv = h3->v.h_double;
+#else
 		      if (!(h3->flags & HIST_STRING) && h3->v.h_vector)
 			tv = *(double *) h3->v.h_vector;
+#endif
 		    }
 		  else
 		    {
@@ -1615,8 +1624,12 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
 	  tv = mynan;
 	  if (h3->flags & HIST_REAL)
 	    {
+#ifdef WAVE_HAS_H_DOUBLE
+	      if (!(h3->flags & HIST_STRING)) tv = h3->v.h_double;
+#else
 	      if (!(h3->flags & HIST_STRING) && h3->v.h_vector)
 		tv = *(double *) h3->v.h_vector;
+#endif
 	    }
 	  else
 	    {
@@ -1710,8 +1723,12 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
       tv = tv2 = mynan;
       if (h->flags & HIST_REAL)
 	{
+#ifdef WAVE_HAS_H_DOUBLE
+	  if (!(h->flags & HIST_STRING)) tv = h->v.h_double;
+#else
 	  if (!(h->flags & HIST_STRING) && h->v.h_vector)
 	    tv = *(double *) h->v.h_vector;
+#endif
 	}
       else
 	{
@@ -1720,8 +1737,12 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
 	}
       if (h2->flags & HIST_REAL)
 	{
+#ifdef WAVE_HAS_H_DOUBLE
+	  if (!(h2->flags & HIST_STRING)) tv2 = h2->v.h_double;
+#else
 	  if (!(h2->flags & HIST_STRING) && h2->v.h_vector)
 	    tv2 = *(double *) h2->v.h_vector;
+#endif
 	}
       else
 	{
@@ -2101,8 +2122,13 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 		    {
 		      if (!(h->flags & HIST_STRING))
 			{
+#ifdef WAVE_HAS_H_DOUBLE
+			  ascii =
+			    convert_ascii_real (t, &h->v.h_double);
+#else
 			  ascii =
 			    convert_ascii_real (t, (double *) h->v.h_vector);
+#endif
 			}
 		      else
 			{
@@ -2812,8 +2838,6 @@ pr_rendertraces (pr_context * prc)
 	      if (!t->vector)
 		{
 		  h = bsearch_node (t->n.nd, GLOBALS->tims.start - t->shift);
-		  DEBUG (printf
-			 ("Bit Trace: %s, %s\n", t->name, t->n.nd->nname));
 		  DEBUG (printf
 			 ("Start time: " TTFormat ", Histent time: " TTFormat
 			  "\n", tims.start, (h->time + shift_timebase)));
@@ -3122,8 +3146,11 @@ print_mif_image (FILE * wave, gdouble px, gdouble py)
 }
 
 /*
- * $Id: print.c,v 1.39 2010/12/21 22:42:05 gtkwave Exp $
+ * $Id: print.c,v 1.40 2011/01/13 17:20:39 gtkwave Exp $
  * $Log: print.c,v $
+ * Revision 1.40  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
  * Revision 1.39  2010/12/21 22:42:05  gtkwave
  * fix to mif_draw_string with respect to out of range character codes
  *
