@@ -62,13 +62,6 @@ for(j=0;j<GLOBALS->num_notebook_pages;j++)
 	}
 }
 
-#if defined __MINGW32__ || defined _MSC_VER
-
-void ptrans_searchbox(char *title) { }
-void install_proc_filter(int which) { } 
-void set_current_translate_proc(char *name) { }
-
-#else
 
 static void regen_display(void)
 {
@@ -118,7 +111,7 @@ static void load_proc_filter(int which, char *name)
   arg = name + strlen(exec_name);
 
   /* remove leading spaces from argument */
-  while (isspace(arg[0])) {
+  while (isspace((int)(unsigned char)arg[0])) {
     arg++;
   }
 
@@ -134,6 +127,7 @@ static void load_proc_filter(int which, char *name)
   }
 
   /* turn the exec_name into an absolute path */
+#if !defined __MINGW32__ && !defined _MSC_VER
   cmd = (char *)malloc_2(strlen(exec_name)+6+1);
   sprintf(cmd, "which %s", exec_name);
   stream = popen(cmd, "r");
@@ -149,6 +143,10 @@ static void load_proc_filter(int which, char *name)
 
   pclose(stream);
   free_2(cmd);
+#else
+  strcpy(abs_path, exec_name);
+#endif
+
 
   /* remove_proc_filter(which, 0); ... should never happen from GUI, but perhaps possible from save files or other weirdness */
   if(!GLOBALS->ttrans_filter[which])
@@ -157,10 +155,15 @@ static void load_proc_filter(int which, char *name)
 	}
 }
 
-void install_proc_filter(int which)
+int install_proc_filter(int which)
 {
 int found = 0;
 
+if((which<0)||(which>=(PROC_FILTER_MAX+1)))
+        {
+        which = 0;
+        }
+
 if(GLOBALS->traces.first)  
         {
         Trptr t = GLOBALS->traces.first;
@@ -180,7 +183,7 @@ if(GLOBALS->traces.first)
 					{
 					t->flags |= TR_PTRANSLATED;
 					}
-                                found = 1;
+                                found++;
                                 }
                         }
                 t=t->t_next;
@@ -191,6 +194,8 @@ if(found)
 	{
 	regen_display();
 	}
+
+return(found);
 }
 
 /************************************************************************/
@@ -445,11 +450,19 @@ if(GLOBALS->num_proc_filters < PROC_FILTER_MAX)
 	}
 }
 
-#endif
 
 /*
- * $Id: ptranslate.c,v 1.12 2010/06/23 05:45:34 gtkwave Exp $
+ * $Id: ptranslate.c,v 1.15 2010/10/02 18:58:55 gtkwave Exp $
  * $Log: ptranslate.c,v $
+ * Revision 1.15  2010/10/02 18:58:55  gtkwave
+ * ctype.h compiler warning fixes (char vs int)
+ *
+ * Revision 1.14  2010/08/25 22:58:23  gtkwave
+ * added process file support for mingw
+ *
+ * Revision 1.13  2010/07/19 21:12:19  gtkwave
+ * added file/proc/trans access functions to Tcl script interpreter
+ *
  * Revision 1.12  2010/06/23 05:45:34  gtkwave
  * warnings fixes
  *
