@@ -902,9 +902,25 @@ if(!(handle=fopen(rcname,"rb")))
 #else
 if(!(handle=fopen(rcname,"rb")))		/* no concept of ~ in win32 */
 	{
-	errno=0;
-	if(GLOBALS->possibly_use_rc_defaults) vanilla_rc();
-	return; /* no .rc file */
+        /* Try to find rcname in USERPROFILE */
+        char *home;
+        char *rcpath;
+
+        home=getenv("USERPROFILE");
+        if (home != NULL) {
+            /* printf("USERPROFILE = %s\n", home); */
+            rcpath=(char *)alloca(strlen(home)+1+strlen(rcname)+1);
+            strcpy(rcpath,home);
+            strcat(rcpath,"\\");
+            strcat(rcpath,rcname);
+            /* printf("rcpath = %s\n", rcpath); */
+        }
+        if ((home == NULL) || (!(handle=fopen(rcpath,"rb")))) {
+            /* printf("No rc file\n"); */
+  	    errno=0;
+	    if(GLOBALS->possibly_use_rc_defaults) vanilla_rc();
+	    return; /* no .rc file */
+	    }
 	} 
 #endif
 
@@ -975,8 +991,11 @@ return;
 }
 
 /*
- * $Id: rc.c,v 1.26 2010/10/26 17:37:35 gtkwave Exp $
+ * $Id: rc.c,v 1.27 2010/12/30 09:22:00 gtkwave Exp $
  * $Log: rc.c,v $
+ * Revision 1.27  2010/12/30 09:22:00  gtkwave
+ * added userprofile patch for win32
+ *
  * Revision 1.26  2010/10/26 17:37:35  gtkwave
  * added initial_signal_window_width rc variable
  *
