@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2005.
+ * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -33,14 +33,11 @@ clist_sigcmp (GtkCList      *clist,
 {  
   char *text1 = NULL;
   char *text2 = NULL;
+  int rc;
 
   GtkCListRow *row1 = (GtkCListRow *) ptr1; 
   GtkCListRow *row2 = (GtkCListRow *) ptr2;
 
-  char *nd1, *nd2;
-  int was_packed1=0, was_packed2=0;
-  int rc;
-  
   switch (row1->cell[clist->sort_column].type)
     {
     case GTK_CELL_TEXT:
@@ -71,13 +68,8 @@ clist_sigcmp (GtkCList      *clist,
   if (!text1)
     return -1;
 
-  nd1 = hier_decompress_flagged(text1, &was_packed1);
-  nd2 = hier_decompress_flagged(text2, &was_packed2);
-  rc = sigcmp(nd1, nd2);
+  rc = sigcmp(text1, text2);
 
-  if(was_packed1) free_2(nd1);
-  if(was_packed2) free_2(nd2);
-    
   return (rc);
 }
 
@@ -1109,8 +1101,14 @@ void searchbox(char *title, GtkSignalFunc func)
 }
 
 /*
- * $Id: search.c,v 1.16 2010/05/27 06:07:24 gtkwave Exp $
+ * $Id: search.c,v 1.18 2011/01/22 01:29:24 gtkwave Exp $
  * $Log: search.c,v $
+ * Revision 1.18  2011/01/22 01:29:24  gtkwave
+ * sourcecode cleanup / warnings fixes
+ *
+ * Revision 1.17  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
  * Revision 1.16  2010/05/27 06:07:24  gtkwave
  * Moved gtk_grab_add() after gtk_widget_show() as newer gtk needs that order.
  *
