@@ -22,6 +22,9 @@ a hierarchy first */
 
 void status_text(char *str)
 {
+int len = strlen(str);
+char ch = len ? str[len-1] : 0;
+
 if(GLOBALS->text_status_c_2)
 	{
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
@@ -32,10 +35,20 @@ if(GLOBALS->text_status_c_2)
 	}
 	else
 	{
-	int len = strlen(str);
-	char ch = len ? str[len-1] : 0;
 	fprintf(stderr, "GTKWAVE | %s%s", str, (ch=='\n') ? "" : "\n");
 	}
+
+{
+char *stemp = wave_alloca(len+1);
+strcpy(stemp, str);
+
+if(ch == '\n')
+	{
+	stemp[len-1] = 0;
+	}
+gtkwavetcl_setvar(WAVE_TCLCB_STATUS_TEXT, stemp, WAVE_TCLCB_STATUS_TEXT_FLAGS);
+}
+
 }
 
 void
@@ -156,8 +169,12 @@ return(table);
 }
    
 /*
- * $Id: status.c,v 1.6 2008/02/12 23:35:42 gtkwave Exp $
+ * $Id: status.c,v 1.7 2010/08/03 01:37:26 gtkwave Exp $
  * $Log: status.c,v $
+ * Revision 1.7  2010/08/03 01:37:26  gtkwave
+ * added gtkwave::cbFromEntryUpdated, gtkwave::cbToEntryUpdated
+ * and gtkwave::cbStatusText.
+ *
  * Revision 1.6  2008/02/12 23:35:42  gtkwave
  * preparing for 3.1.5 revision bump
  *
