@@ -127,11 +127,16 @@ void edge_search(int direction); /* from edgebuttons.c */
 int mprintf(const char *fmt, ... );
 void delete_mprintf(void);
 
+void tracesearchbox(const char *title, GtkSignalFunc func, gpointer data);
+
 #endif
 
 /*
- * $Id: strace.h,v 1.8 2010/02/24 17:35:35 gtkwave Exp $
+ * $Id: strace.h,v 1.9 2010/07/01 23:02:41 gtkwave Exp $
  * $Log: strace.h,v $
+ * Revision 1.9  2010/07/01 23:02:41  gtkwave
+ * header file cleanup
+ *
  * Revision 1.8  2010/02/24 17:35:35  gtkwave
  * gtk1 compile fixes
  *
