@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,16 +18,39 @@
 #include "tree.h"
 #include "vcd.h"
 
-
 enum TreeBuildTypes { MAKETREE_FLATTEN, MAKETREE_LEAF, MAKETREE_NODE };
 
 
+#ifdef WAVE_USE_STRUCT_PACKING
+struct tree *talloc_2(size_t siz)
+{
+if(GLOBALS->talloc_pool_base)
+	{
+	if((siz + GLOBALS->talloc_idx) <= WAVE_TALLOC_POOL_SIZE)
+		{
+		unsigned char *m = GLOBALS->talloc_pool_base + GLOBALS->talloc_idx;
+		GLOBALS->talloc_idx += siz;
+		return((struct tree *)m);
+		}
+	else
+	if(siz >= WAVE_TALLOC_ALTREQ_SIZE)
+		{
+		return(calloc_2(1, siz));
+		}
+	}
+
+GLOBALS->talloc_pool_base = calloc_2(1, WAVE_TALLOC_POOL_SIZE);
+GLOBALS->talloc_idx = 0;
+return(talloc_2(siz));
+}
+#endif
+
+
 /*
  * init pointers needed for n-way tree
  */
 void init_tree(void)
 {
-/* treeroot=(struct tree *)calloc_2(1,sizeof(struct tree)); */
 GLOBALS->module_tree_c_1=(char *)malloc_2(GLOBALS->longestname+1);
 }
 
@@ -67,9 +90,20 @@ for(;;)
 /*
  * decorated module add
  */
-void allocate_and_decorate_module_tree_node(unsigned char ttype, const char *scopename)
+void allocate_and_decorate_module_tree_node(unsigned char ttype, const char *scopename, const char *compname, uint32_t scopename_len, uint32_t compname_len)
 {
 struct tree *t;
+int mtyp = WAVE_T_WHICH_UNDEFINED_COMPNAME;
+
+if(compname && compname[0] && strcmp(scopename, compname))
+	{
+	int ix = add_to_comp_name_table(compname, compname_len);
+	if(ix)
+		{
+		ix--;
+		mtyp = WAVE_T_WHICH_COMPNAME_START - ix;
+		}
+	}
 
 if(GLOBALS->treeroot)
 	{
@@ -86,10 +120,10 @@ if(GLOBALS->treeroot)
 			t = t->next;
 			}
 
-		t = calloc_2(1, sizeof(struct tree) + strlen(scopename));
+		t = talloc_2(sizeof(struct tree) + scopename_len);
 		strcpy(t->name, scopename);
 		t->kind = ttype;
-		t->which = -1;
+		t->t_which = mtyp;
 
 		if(GLOBALS->mod_tree_parent->child)
 			{
@@ -111,10 +145,10 @@ if(GLOBALS->treeroot)
 			t = t->next;
 			}
 
-		t = calloc_2(1, sizeof(struct tree) + strlen(scopename));
+		t = talloc_2(sizeof(struct tree) + scopename_len);
 		strcpy(t->name, scopename);
 		t->kind = ttype;
-		t->which = -1;
+		t->t_which = mtyp;
 
 		t->next = GLOBALS->treeroot;
 		GLOBALS->mod_tree_parent = GLOBALS->treeroot = t;
@@ -122,10 +156,10 @@ if(GLOBALS->treeroot)
 	}
 	else
 	{
-	t = calloc_2(1, sizeof(struct tree) + strlen(scopename));
+	t = talloc_2(sizeof(struct tree) + scopename_len);
 	strcpy(t->name, scopename);
 	t->kind = ttype;
-	t->which = -1;
+	t->t_which = mtyp;
 
 	GLOBALS->mod_tree_parent = GLOBALS->treeroot = t;
 	}
@@ -230,10 +264,10 @@ while(t)
 		treedebug(t->child, s2);
 		}
 
-	if(t->which>=0) /* for when valid netnames like A.B.C, A.B.C.D exist (not legal excluding texsim) */
+	if(t->t_which>=0) /* for when valid netnames like A.B.C, A.B.C.D exist (not legal excluding texsim) */
 			/* otherwise this would be an 'else' */
 		{
-		printf("%3d) %s\n", t->which, s2);
+		printf("%3d) %s\n", t->t_which, s2);
 		}
 
 	free_2(s2);
@@ -248,18 +282,18 @@ char *tmp, *tmp2, *tmp3;
 gchar *text [1];
 GdkDrawable *pxm, *msk;
 
-if(t2->which!=-1)
+if(t2->t_which >= 0)
 	{
-        if(GLOBALS->facs[t2->which]->vec_root)
+        if(GLOBALS->facs[t2->t_which]->vec_root)
         	{
                 if(GLOBALS->autocoalesce)
                 	{
-                        if(GLOBALS->facs[t2->which]->vec_root!=GLOBALS->facs[t2->which])
+                        if(GLOBALS->facs[t2->t_which]->vec_root!=GLOBALS->facs[t2->t_which])
                         	{
 				return(NULL);
                                 }
 
-                        tmp2=makename_chain(GLOBALS->facs[t2->which]);
+                        tmp2=makename_chain(GLOBALS->facs[t2->t_which]);
                         tmp3=leastsig_hiername(tmp2);
                         tmp=wave_alloca(strlen(tmp3)+4);
                         strcpy(tmp,   "[] ");
@@ -280,7 +314,25 @@ if(t2->which!=-1)
 	}
         else
         {
-        tmp=t2->name;
+	if(t2->t_which == WAVE_T_WHICH_UNDEFINED_COMPNAME)
+		{
+        	tmp=t2->name;
+		}
+		else
+		{
+		int thidx = -t2->t_which + WAVE_T_WHICH_COMPNAME_START;
+		if((thidx >= 0) && (thidx < GLOBALS->comp_name_serial))
+			{
+			char *sc = GLOBALS->comp_name_idx[thidx];
+			int tlen = strlen(t2->name) + 2 + 1 + strlen(sc) + 1 + 1;
+			tmp = wave_alloca(tlen);
+			sprintf(tmp, "%s  (%s)", t2->name, sc);
+			}
+			else
+			{
+	        	tmp=t2->name;	/* should never get a value out of range here! */
+			}
+		}
         }
 
 text[0]=tmp;
@@ -383,7 +435,7 @@ struct tree *t2 = *(struct tree **)v2;
 return(sigcmp(t2->name, t1->name));	/* because list must be in rvs */
 }
 
-void treesort(struct tree *t, struct tree *p)
+static void treesort_2(struct tree *t, struct tree *p, struct tree ***tm, int *tm_siz)
 {
 struct tree *it;
 struct tree **srt;
@@ -398,13 +450,21 @@ if(t->next)
 		cnt++;
 		it=it->next;
 		} while(it);
-	
-	srt = malloc_2(cnt * sizeof(struct tree *)); /* was previously wave_alloca but with too many signals the stack overflows */
+
+	if(cnt > *tm_siz)
+		{
+		*tm_siz = cnt;
+		if(*tm) { free_2(*tm); }
+		*tm = malloc_2((cnt+1) * sizeof(struct tree *));
+		}
+	srt = *tm;
+
 	for(i=0;i<cnt;i++)
 		{
 		srt[i] = t;
 		t=t->next;
 		}
+	srt[i] = NULL;
 
 	qsort((void *)srt, cnt, sizeof(struct tree *), tree_qsort_cmp);
 
@@ -417,29 +477,42 @@ if(t->next)
 		GLOBALS->treeroot = srt[0];
 		}
 
-	for(i=0;i<(cnt-1);i++)
+	for(i=0;i<cnt;i++)
 		{
 		srt[i]->next = srt[i+1];
-		if(srt[i]->child)
-			{
-			treesort(srt[i]->child, srt[i]);
-			}
-		}
-	srt[i]->next = NULL;
-	if(srt[i]->child)
-		{
-		treesort(srt[i]->child, srt[i]);
 		}
 
-	free_2(srt);
+	it = srt[0];
+	for(i=0;i<cnt;i++)
+		{
+		if(it->child)
+			{
+			treesort_2(it->child, it, tm, tm_siz);
+			}
+		it = it->next;
+		}
 	}
 else if (t->child)
 	{
-	treesort(t->child, t);
+	treesort_2(t->child, t, tm, tm_siz);
 	}
 }
 
 
+void treesort(struct tree *t, struct tree *p)
+{
+struct tree **tm = NULL;
+int tm_siz = 0;
+
+treesort_2(t, p, &tm, &tm_siz);
+if(tm)
+	{
+	free_2(tm);
+	}
+
+}
+
+
 void order_facs_from_treesort_2(struct tree *t)
 {
 while(t)
@@ -449,11 +522,11 @@ while(t)
 		order_facs_from_treesort_2(t->child);
 		}
 
-	if(t->which>=0) /* for when valid netnames like A.B.C, A.B.C.D exist (not legal excluding texsim) */
+	if(t->t_which>=0) /* for when valid netnames like A.B.C, A.B.C.D exist (not legal excluding texsim) */
 			/* otherwise this would be an 'else' */
 		{
-		GLOBALS->facs2_tree_c_1[GLOBALS->facs2_pos_tree_c_1] = GLOBALS->facs[t->which];
-		t->which = GLOBALS->facs2_pos_tree_c_1--;
+		GLOBALS->facs2_tree_c_1[GLOBALS->facs2_pos_tree_c_1] = GLOBALS->facs[t->t_which];
+		t->t_which = GLOBALS->facs2_pos_tree_c_1--;
 		}
 
 	t=t->next;
@@ -532,12 +605,12 @@ rs:		s=get_module_name(s);
 				}
 			}
 
-		nt=(struct tree *)calloc_2(1,sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
+		nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
 		memcpy(nt->name, GLOBALS->module_tree_c_1, GLOBALS->module_len_tree_c_1);
 
 		if(s)
 			{
-			nt->which=-1;
+			nt->t_which = WAVE_T_WHICH_UNDEFINED_COMPNAME;
 
 			if(prevt)				/* make first in chain */
 				{
@@ -553,7 +626,7 @@ rs:		s=get_module_name(s);
 			else
 			{
 			nt->child = prevt;			/* parent */
-			nt->which = which;
+			nt->t_which = which;
 			nt->next = GLOBALS->terminals_tchain_tree_c_1;
 			GLOBALS->terminals_tchain_tree_c_1 = nt;
 			return;
@@ -565,19 +638,19 @@ rs:		s=get_module_name(s);
 			{
 			s=get_module_name(s);
 		
-			nt=(struct tree *)calloc_2(1,sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
+			nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
 			memcpy(nt->name, GLOBALS->module_tree_c_1, GLOBALS->module_len_tree_c_1);
 
 			if(s)
 				{
-				nt->which = -1;
+				nt->t_which = WAVE_T_WHICH_UNDEFINED_COMPNAME;
 				t->child = nt;
 				t = nt;
 				}
 				else
 				{
 				nt->child = t;			/* parent */
-				nt->which = which;
+				nt->t_which = which;
 				nt->next = GLOBALS->terminals_tchain_tree_c_1;
 				GLOBALS->terminals_tchain_tree_c_1 = nt;
 				}
@@ -591,10 +664,10 @@ else
 		{
 		s=get_module_name(s);
 
-		nt=(struct tree *)calloc_2(1,sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
+		nt=(struct tree *)talloc_2(sizeof(struct tree)+GLOBALS->module_len_tree_c_1);
 		memcpy(nt->name, GLOBALS->module_tree_c_1, GLOBALS->module_len_tree_c_1);
 
-		if(!s) nt->which=which; else nt->which=-1;
+		if(!s) nt->t_which=which; else nt->t_which = WAVE_T_WHICH_UNDEFINED_COMPNAME;
 
 		if(GLOBALS->treeroot)
 			{
@@ -735,8 +808,29 @@ if(!GLOBALS->hier_grouping)
 #endif
 
 /*
- * $Id: tree.c,v 1.9 2010/09/23 22:04:55 gtkwave Exp $
+ * $Id: tree.c,v 1.16 2011/01/23 21:55:54 gtkwave Exp $
  * $Log: tree.c,v $
+ * Revision 1.16  2011/01/23 21:55:54  gtkwave
+ * more optimizations
+ *
+ * Revision 1.15  2011/01/21 22:40:28  gtkwave
+ * pass string lengths from api directly to code to avoid length calculations
+ *
+ * Revision 1.14  2011/01/19 16:18:19  gtkwave
+ * fix for large allocations of tree alloc
+ *
+ * Revision 1.13  2011/01/19 06:36:31  gtkwave
+ * added tree allocation pool when misaligned structs are enabled
+ *
+ * Revision 1.12  2011/01/18 02:38:35  gtkwave
+ * added extra spacing between component type name for readability
+ *
+ * Revision 1.11  2011/01/18 00:00:12  gtkwave
+ * preliminary tree component support
+ *
+ * Revision 1.10  2011/01/17 19:24:21  gtkwave
+ * tree modifications to support decorated internal hierarchy nodes
+ *
  * Revision 1.9  2010/09/23 22:04:55  gtkwave
  * added incremental SST build code
  *
