@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2010.
+ * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -130,9 +130,13 @@ static char *tokens[]={ "var", "end", "scope", "upscope",
  * histent structs are NEVER freed so this is OK..
  * (we are allocating as many entries that fit in 64k minus the size of the two
  * bookkeeping void* pointers found in the malloc_2/free_2 routines in
- * debug.c)
+ * debug.c--unless Judy, then can dispense with pointer subtraction)
  */
+#ifdef _WAVE_HAVE_JUDY
+#define VCD_HISTENT_GRANULARITY ( (64*1024) / sizeof(HistEnt) )
+#else
 #define VCD_HISTENT_GRANULARITY ( ( (64*1024)-(2*sizeof(void *)) ) / sizeof(HistEnt) )
+#endif
 
 struct HistEnt *histent_calloc(void)
 {
@@ -349,13 +353,13 @@ return((int)(*GLOBALS->vst_vcd_c_1));
 }
 
 
-static signed char getch(void) {
+static inline signed char getch(void) {
   signed char ch = ((GLOBALS->vst_vcd_c_1!=GLOBALS->vend_vcd_c_1)?((int)(*GLOBALS->vst_vcd_c_1)):(getch_fetch()));
   GLOBALS->vst_vcd_c_1++;
   return(ch);
 }
 
-static signed char getch_peek(void) {
+static inline signed char getch_peek(void) {
   signed char ch = ((GLOBALS->vst_vcd_c_1!=GLOBALS->vend_vcd_c_1)?((int)(*GLOBALS->vst_vcd_c_1)):(getch_fetch()));
   /* no increment */
   return(ch);
@@ -1148,7 +1152,7 @@ for(;;)
 				strcpy(s->str, GLOBALS->yytext_vcd_c_1);
 				s->mod_tree_parent = GLOBALS->mod_tree_parent;
 
-				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_c_1);
+				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_c_1, NULL, GLOBALS->yylen_vcd_c_1, 0);
 
 				if(GLOBALS->slistcurr)
 					{
@@ -1886,7 +1890,11 @@ switch(ch)
 		he=histent_calloc();
 		he->flags=HIST_REAL;
 	        he->time=-1;
+#ifdef WAVE_HAS_H_DOUBLE
+		he->v.h_double = strtod("NaN", NULL);
+#else
 	        he->v.h_vector=NULL;
+#endif
 	
 		n->curr=he;
 		n->head.next=he;
@@ -1899,12 +1907,18 @@ switch(ch)
 	
 		if(
 #ifndef TRACK_AND_HOLD_FIX
+#ifdef WAVE_HAS_H_DOUBLE
+		  (vector&&(n->curr->v.h_double!=*(double *)vector))
+#else
 		  (n->curr->v.h_vector&&vector&&(*(double *)n->curr->v.h_vector!=*(double *)vector))
+#endif
 #else
 		  (1)
 #endif
 			||(tim==GLOBALS->start_time_vcd_c_1)
+#ifndef WAVE_HAS_H_DOUBLE
 			||(!n->curr->v.h_vector)
+#endif
 			||(GLOBALS->vcd_preserve_glitches)
 			) /* same region == go skip */ 
 	        	{
@@ -1912,9 +1926,12 @@ switch(ch)
 				{
 				DEBUG(printf("Warning: Real number Glitch at time ["TTFormat"] Signal [%p].\n",
 					tim, n));
+#ifdef WAVE_HAS_H_DOUBLE
+				n->curr->v.h_double = *((double *)vector);
+#else
 				if(n->curr->v.h_vector) free_2(n->curr->v.h_vector);
 				n->curr->v.h_vector=vector;		/* we have a glitch! */
-	
+#endif
 				GLOBALS->num_glitches_vcd_c_2++;
 				if(!(n->curr->flags&HIST_GLITCH))
 					{
@@ -1927,8 +1944,11 @@ switch(ch)
 	                	he=histent_calloc();
 				he->flags=HIST_REAL;
 	                	he->time=tim;
+#ifdef WAVE_HAS_H_DOUBLE
+				he->v.h_double = *((double *)vector);
+#else
 	                	he->v.h_vector=vector;
-	
+#endif	
 	                	n->curr->next=he;
 				n->curr=he;
 	                	GLOBALS->regions+=regadd;
@@ -1936,8 +1956,13 @@ switch(ch)
 	                }
 			else
 			{
+#ifndef WAVE_HAS_H_DOUBLE
 			free_2(vector);
+#endif
 			}
+#ifdef WAVE_HAS_H_DOUBLE
+		free_2(vector);
+#endif
 	       }
 	break;
 	}
@@ -2362,8 +2387,6 @@ void vcd_sortfacs(void)
 {
 int i;
 
-create_hier_array();
-
 GLOBALS->facs=(struct symbol **)malloc_2(GLOBALS->numfacs*sizeof(struct symbol *));
 GLOBALS->curnode=GLOBALS->firstnode;
 for(i=0;i<GLOBALS->numfacs;i++)
@@ -2417,18 +2440,7 @@ init_tree();
 for(i=0;i<GLOBALS->numfacs;i++)
 {                       
 char *n = GLOBALS->facs[i]->name;
-int was_packed;
-char *recon = hier_decompress_flagged(n, &was_packed);
-
-if(was_packed)
-	{
-	build_tree_from_name(recon, i);
-	free_2(recon);
-	}
-	else
-	{
-	build_tree_from_name(n, i);
-	}
+build_tree_from_name(n, i);
 
 if(GLOBALS->escaped_names_found_vcd_c_1)
 	{
@@ -2656,8 +2668,23 @@ return(GLOBALS->max_time);
 /*******************************************************************************/
 
 /*
- * $Id: vcd.c,v 1.42 2010/12/19 07:59:10 gtkwave Exp $
+ * $Id: vcd.c,v 1.47 2011/01/23 21:55:54 gtkwave Exp $
  * $Log: vcd.c,v $
+ * Revision 1.47  2011/01/23 21:55:54  gtkwave
+ * more optimizations
+ *
+ * Revision 1.46  2011/01/21 22:40:29  gtkwave
+ * pass string lengths from api directly to code to avoid length calculations
+ *
+ * Revision 1.45  2011/01/18 00:00:12  gtkwave
+ * preliminary tree component support
+ *
+ * Revision 1.44  2011/01/16 07:56:08  gtkwave
+ * inlining of character get functions
+ *
+ * Revision 1.43  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
  * Revision 1.42  2010/12/19 07:59:10  gtkwave
  * warnings fixes
  *
