@@ -59,7 +59,7 @@ VCDNAM_ESCAPE };
 enum VarTypes { V_EVENT, V_PARAMETER,
                 V_INTEGER, V_REAL, V_REAL_PARAMETER=V_REAL, V_REALTIME=V_REAL, V_REG, V_SUPPLY0,
                 V_SUPPLY1, V_TIME, V_TRI, V_TRIAND, V_TRIOR,
-                V_TRIREG, V_TRI0, V_TRI1, V_WAND, V_WIRE, V_WOR, V_PORT, V_IN=V_PORT, V_OUT=V_PORT, V_INOUT=V_PORT,
+                V_TRIREG, V_TRI0, V_TRI1, V_WAND, V_WIRE, V_WOR, V_PORT, V_IN=V_PORT, V_OUT=V_PORT, V_INOUT=V_PORT, V_STRINGTYPE,
                 V_END, V_LB, V_COLON, V_RB, V_STRING };
 #endif
 
@@ -83,12 +83,16 @@ struct slist
 {  
 struct slist *next;
 char *str;
-int len;
-
 struct tree *mod_tree_parent;
+int len;
 };
 
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(push)
+#pragma pack(1)
+#endif
+
 struct vcdsymbol
 {
 struct vcdsymbol *root, *chain;
@@ -97,16 +101,22 @@ struct symbol *sym_chain;
 struct vcdsymbol *next;
 char *name;
 char *id;
-unsigned int nid;
-unsigned char vartype;
-int msi, lsi;
-int size;
 char *value;
 struct Node **narray;
-hptr         *tr_array;   /* points to synthesized trailers (which can move) */
-hptr         *app_array;   /* points to hptr to append to (which can move) */
+hptr *tr_array;   /* points to synthesized trailers (which can move) */
+hptr *app_array;   /* points to hptr to append to (which can move) */
+
+unsigned int nid;
+int msi, lsi;
+int size;
+
+unsigned char vartype;
 };
 
+#ifdef WAVE_USE_STRUCT_PACKING
+#pragma pack(pop)
+#endif
+
 
 char *build_slisthier(void);
 void append_vcd_slisthier(char *str);
@@ -126,8 +136,14 @@ int vcd_keyword_code(const char *s, unsigned int len);
 #endif
 
 /*
- * $Id: vcd.h,v 1.9 2010/03/01 19:19:50 gtkwave Exp $
+ * $Id: vcd.h,v 1.11 2010/12/17 06:29:20 gtkwave Exp $
  * $Log: vcd.h,v $
+ * Revision 1.11  2010/12/17 06:29:20  gtkwave
+ * Added --enable-struct-pack configure flag
+ *
+ * Revision 1.10  2010/12/12 18:32:45  gtkwave
+ * add "string" variable type to parsing of vcd variable declarations
+ *
  * Revision 1.9  2010/03/01 19:19:50  gtkwave
  * more hier_pfx code movement into hierpack.c
  *
