@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -345,13 +345,13 @@ if(!rd) return(-1);
 return((int)(*GLOBALS->vst_vcd_partial_c_2));
 }
 
-static signed char getch(void) {
+static inline signed char getch(void) {
   signed char ch = ((GLOBALS->vst_vcd_partial_c_2!=GLOBALS->vend_vcd_partial_c_2)?((int)(*GLOBALS->vst_vcd_partial_c_2)):(getch_fetch()));
   if(ch>=0) { GLOBALS->vst_vcd_partial_c_2++; };
   return(ch);
 }
 
-static signed char getch_peek(void) {
+static inline signed char getch_peek(void) {
   signed char ch = ((GLOBALS->vst_vcd_partial_c_2!=GLOBALS->vend_vcd_partial_c_2)?((int)(*GLOBALS->vst_vcd_partial_c_2)):(getch_fetch()));
   /* no increment */
   return(ch);
@@ -1115,7 +1115,7 @@ for(;;)
 				strcpy(s->str, GLOBALS->yytext_vcd_partial_c_2);
 				s->mod_tree_parent = GLOBALS->mod_tree_parent;
 
-				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_partial_c_2);
+				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_partial_c_2, NULL, GLOBALS->yylen_vcd_partial_c_2, 0);
 
 				if(GLOBALS->slistcurr)
 					{
@@ -1782,8 +1782,11 @@ switch(ch)
 		he=histent_calloc();
 		he->flags=HIST_REAL;
 	        he->time=-1;
+#ifdef WAVE_HAS_H_DOUBLE
+                he->v.h_double = strtod("NaN", NULL);
+#else
 	        he->v.h_vector=NULL;
-	
+#endif	
 		n->curr=he;
 		n->head.next=he;
 	
@@ -1795,9 +1798,15 @@ switch(ch)
 		if(regadd) { tim*=(GLOBALS->time_scale); }
 	
 		if(
+#ifdef WAVE_HAS_H_DOUBLE
+                  (vector&&(n->curr->v.h_double!=*(double *)vector))
+#else
 		  (n->curr->v.h_vector&&vector&&(*(double *)n->curr->v.h_vector!=*(double *)vector))
+#endif
 			||(tim==GLOBALS->start_time_vcd_partial_c_2)
+#ifndef WAVE_HAS_H_DOUBLE
 			||(!n->curr->v.h_vector)
+#endif
 			||(GLOBALS->vcd_preserve_glitches)
 			) /* same region == go skip */ 
 	        	{
@@ -1805,9 +1814,12 @@ switch(ch)
 				{
 				DEBUG(printf("Warning: Real number Glitch at time ["TTFormat"] Signal [%p].\n",
 					tim, n));
+#ifdef WAVE_HAS_H_DOUBLE
+                                n->curr->v.h_double = *((double *)vector);
+#else
 				if(n->curr->v.h_vector) free_2(n->curr->v.h_vector);
 				n->curr->v.h_vector=vector;		/* we have a glitch! */
-	
+#endif	
 				GLOBALS->num_glitches_vcd_partial_c_3++;
 				if(!(n->curr->flags&HIST_GLITCH))
 					{
@@ -1820,8 +1832,11 @@ switch(ch)
 	                	he=histent_calloc();
 				he->flags=HIST_REAL;
 	                	he->time=tim;
+#ifdef WAVE_HAS_H_DOUBLE
+                                he->v.h_double = *((double *)vector);
+#else
 	                	he->v.h_vector=vector;
-	
+#endif	
 	                	n->curr->next=he;
 				n->curr=he;
 	                	GLOBALS->regions+=regadd;
@@ -1829,8 +1844,13 @@ switch(ch)
 	                }
 			else
 			{
+#ifndef WAVE_HAS_H_DOUBLE
 			free_2(vector);
+#endif
 			}
+#ifdef WAVE_HAS_H_DOUBLE
+	        free_2(vector);
+#endif
 	       }
 	break;
 	}
@@ -2568,8 +2588,17 @@ gtkwave_main_iteration();
 }
 
 /*
- * $Id: vcd_partial.c,v 1.42 2010/12/19 07:59:10 gtkwave Exp $
+ * $Id: vcd_partial.c,v 1.45 2011/01/21 22:40:29 gtkwave Exp $
  * $Log: vcd_partial.c,v $
+ * Revision 1.45  2011/01/21 22:40:29  gtkwave
+ * pass string lengths from api directly to code to avoid length calculations
+ *
+ * Revision 1.44  2011/01/18 00:00:12  gtkwave
+ * preliminary tree component support
+ *
+ * Revision 1.43  2011/01/16 07:56:08  gtkwave
+ * inlining of character get functions
+ *
  * Revision 1.42  2010/12/19 07:59:10  gtkwave
  * warnings fixes
  *
