@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009.
+ * Copyright (c) Tony Bybell 1999-2011.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -840,13 +840,13 @@ if(GLOBALS->vcd_fsiz_vcd_recoder_c_2)
 return((int)(*GLOBALS->vst_vcd_recoder_c_3));
 }
         
-static signed char getch(void) {
+static inline signed char getch(void) {
   signed char ch = (GLOBALS->vst_vcd_recoder_c_3!=GLOBALS->vend_vcd_recoder_c_3)?((int)(*GLOBALS->vst_vcd_recoder_c_3)):(getch_fetch());
   GLOBALS->vst_vcd_recoder_c_3++;
   return(ch);
 }
 
-static signed char getch_peek(void) {
+static inline signed char getch_peek(void) {
   signed char ch = (GLOBALS->vst_vcd_recoder_c_3!=GLOBALS->vend_vcd_recoder_c_3)?((int)(*GLOBALS->vst_vcd_recoder_c_3)):(getch_fetch());
   /* no increment */
   return(ch);
@@ -1471,7 +1471,7 @@ for(;;)
 				strcpy(s->str, GLOBALS->yytext_vcd_recoder_c_3);
 				s->mod_tree_parent = GLOBALS->mod_tree_parent;
 
-				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_recoder_c_3);
+				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_recoder_c_3, NULL, GLOBALS->yylen_vcd_recoder_c_3, 0);
 
 				if(GLOBALS->slistcurr)
 					{
@@ -1931,14 +1931,6 @@ for(;;)
 				}
 
 			bail:
-			if((v) && (GLOBALS->do_hier_compress))
-				{
-				char *old_name = v->name;
-				int was_packed;
-				v->name = hier_compress(v->name, HIERPACK_ADD, &was_packed);
-				if(was_packed) free_2(old_name);
-				}
-
 			if(vtok!=V_END) sync_end(NULL);
 			break;
 			}
@@ -2207,7 +2199,11 @@ switch(ch)
 		he=histent_calloc();
 		he->flags=HIST_REAL;
 	        he->time=-1;
+#ifdef WAVE_HAS_H_DOUBLE
+                he->v.h_double = strtod("NaN", NULL);
+#else
 	        he->v.h_vector=NULL;
+#endif
 	
 		n->curr=he;
 		n->head.next=he;
@@ -2219,9 +2215,15 @@ switch(ch)
 		if(regadd) { tim*=(GLOBALS->time_scale); }
 	
 		if(
+#ifdef WAVE_HAS_H_DOUBLE
+                  (vector&&(n->curr->v.h_double!=*(double *)vector))
+#else
 		  (n->curr->v.h_vector&&vector&&(*(double *)n->curr->v.h_vector!=*(double *)vector))
+#endif
 			||(tim==GLOBALS->start_time_vcd_recoder_c_3)
+#ifndef WAVE_HAS_H_DOUBLE
 			||(!n->curr->v.h_vector)
+#endif
 			||(GLOBALS->vcd_preserve_glitches)
 			) /* same region == go skip */ 
 	        	{
@@ -2229,9 +2231,12 @@ switch(ch)
 				{
 				DEBUG(printf("Warning: Real number Glitch at time ["TTFormat"] Signal [%p].\n",
 					tim, n));
+#ifdef WAVE_HAS_H_DOUBLE
+                                n->curr->v.h_double = *((double *)vector);
+#else
 				if(n->curr->v.h_vector) free_2(n->curr->v.h_vector);
 				n->curr->v.h_vector=vector;		/* we have a glitch! */
-	
+#endif	
 				GLOBALS->num_glitches_vcd_recoder_c_4++;
 				if(!(n->curr->flags&HIST_GLITCH))
 					{
@@ -2244,8 +2249,11 @@ switch(ch)
 	                	he=histent_calloc();
 				he->flags=HIST_REAL;
 	                	he->time=tim;
+#ifdef WAVE_HAS_H_DOUBLE
+				he->v.h_double = *((double *)vector);
+#else
 	                	he->v.h_vector=vector;
-	
+#endif
 	                	n->curr->next=he;
 				n->curr=he;
 	                	GLOBALS->regions+=regadd;
@@ -2253,8 +2261,13 @@ switch(ch)
 	                }
 			else
 			{
+#ifndef WAVE_HAS_H_DOUBLE
 			free_2(vector);
+#endif
 			}
+#ifdef WAVE_HAS_H_DOUBLE
+	        free_2(vector);
+#endif
 	       }
 	break;
 	}
@@ -3270,8 +3283,20 @@ np->mv.mvlfac_vlist = NULL;
 }
 
 /*
- * $Id: vcd_recoder.c,v 1.52 2010/12/19 07:59:10 gtkwave Exp $
+ * $Id: vcd_recoder.c,v 1.56 2011/01/21 22:40:29 gtkwave Exp $
  * $Log: vcd_recoder.c,v $
+ * Revision 1.56  2011/01/21 22:40:29  gtkwave
+ * pass string lengths from api directly to code to avoid length calculations
+ *
+ * Revision 1.55  2011/01/18 00:00:12  gtkwave
+ * preliminary tree component support
+ *
+ * Revision 1.54  2011/01/16 07:56:08  gtkwave
+ * inlining of character get functions
+ *
+ * Revision 1.53  2011/01/13 17:20:39  gtkwave
+ * rewrote hierarchy / facility packing code
+ *
  * Revision 1.52  2010/12/19 07:59:10  gtkwave
  * warnings fixes
  *
