@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2006-8.
+ * Copyright (c) Tony Bybell 2006-9.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,16 +31,28 @@
 
 void vlist_init_spillfile(void)
 {
-#if defined _MSC_VER || defined __MINGW32__
-GLOBALS->vlist_handle = tmpfile();
-fputc('!', GLOBALS->vlist_handle);
-GLOBALS->vlist_bytes_written = 1;
-#else
-int fd_dummy;
-char *nam = tmpnam_2(NULL, &fd_dummy);
-
-if(nam)
+if(GLOBALS->use_fastload)
 	{
+	char *fname = malloc_2(strlen(GLOBALS->loaded_file_name) + 4 + 1);
+	sprintf(fname, "%s.idx", GLOBALS->loaded_file_name);
+		
+	GLOBALS->vlist_handle = fopen(fname, "w+b");
+
+	free_2(fname);
+
+	fputc('!', GLOBALS->vlist_handle);
+	GLOBALS->vlist_bytes_written = 1;
+	}
+else
+	{
+#if defined _MSC_VER || defined __MINGW32__
+	GLOBALS->vlist_handle = tmpfile();
+	fputc('!', GLOBALS->vlist_handle);
+	GLOBALS->vlist_bytes_written = 1;
+#else
+	int fd_dummy;
+	char *nam = tmpnam_2(NULL, &fd_dummy);
+
 	GLOBALS->vlist_handle = fopen(nam, "w+b");
 	
 	unlink(nam);
@@ -48,8 +60,8 @@ if(nam)
 
 	fputc('!', GLOBALS->vlist_handle);
 	GLOBALS->vlist_bytes_written = 1;
-	}
 #endif
+	}
 }
 
 void vlist_kill_spillfile(void)
@@ -62,6 +74,137 @@ if(GLOBALS->vlist_handle)
 }
 
 
+/* machine-independent header i/o 
+ */
+static int vlist_fread_hdr(struct vlist_t *vl, FILE *f)
+{
+unsigned long val; 
+unsigned int vali;
+int ch, shamt, rc = 0;
+
+val = 0; shamt = 0;
+do
+	{
+	ch = fgetc(f);
+	if(ch == EOF) goto bail;	
+
+	val |= ((unsigned long)(ch & 0x7f)) << shamt;
+	shamt += 7;
+	} while(!(ch & 0x80));
+vl->next = (struct vlist_t *)val;
+
+vali = 0; shamt = 0;
+do
+	{
+	ch = fgetc(f);
+	if(ch == EOF) goto bail;	
+
+	vali |= ((unsigned int)(ch & 0x7f)) << shamt;
+	shamt += 7;
+	} while(!(ch & 0x80));
+vl->siz = (unsigned int)vali;
+
+vali = 0; shamt = 0;
+do
+	{
+	ch = fgetc(f);
+	if(ch == EOF) goto bail;	
+
+	vali |= ((unsigned int)(ch & 0x7f)) << shamt;
+	shamt += 7;
+	} while(!(ch & 0x80));
+vl->offs = (vali & 1) ? (unsigned int)(-(int)(vali >> 1)) : (vali >> 1);
+
+vali = 0; shamt = 0;
+do
+	{
+	ch = fgetc(f);
+	if(ch == EOF) goto bail;	
+
+	vali |= ((unsigned int)(ch & 0x7f)) << shamt;
+	shamt += 7;
+	} while(!(ch & 0x80));
+vl->elem_siz = (unsigned int)vali;
+
+rc = 1;
+
+bail: 
+return(rc);
+}
+
+
+static int vlist_fwrite(struct vlist_t *vl, unsigned int rsiz, FILE *f)
+{
+unsigned char mem[ 4 * sizeof(long) * 2];
+unsigned char *pnt = mem;
+unsigned long val, nxt;
+unsigned int vali, nxti;
+int offs_as_int;
+int rc;
+int len = 0;
+
+val = (unsigned long)(vl->next);
+while((nxt = val>>7))
+        {
+        *(pnt++) = (val&0x7f);
+        val = nxt;
+        }           
+*(pnt++) = (val&0x7f) | 0x80;
+
+
+vali = (vl->siz);
+while((nxti = vali>>7))
+        {
+        *(pnt++) = (vali&0x7f);
+        vali = nxti;
+        }           
+*(pnt++) = (vali&0x7f) | 0x80;
+
+offs_as_int = (int)(vl->offs);
+if(offs_as_int < 0)
+	{
+	offs_as_int = -offs_as_int;	/* reduce number of one bits propagating left by making sign bit the lsb */
+	offs_as_int <<= 1;
+	offs_as_int |= 1;
+	}
+	else
+	{
+	offs_as_int <<= 1;
+	}
+
+vali = (unsigned int)(offs_as_int);
+while((nxti = vali>>7))
+        {
+        *(pnt++) = (vali&0x7f);
+        vali = nxti;
+        }           
+*(pnt++) = (vali&0x7f) | 0x80;
+
+vali = (unsigned int)(vl->elem_siz);
+while((nxti = vali>>7))
+        {
+        *(pnt++) = (vali&0x7f);
+        vali = nxti;
+        }           
+*(pnt++) = (vali&0x7f) | 0x80;
+
+rc = fwrite(mem, 1, (len = (pnt - mem)), f);
+if(rc)
+	{
+        unsigned int wrlen = (rsiz - sizeof(struct vlist_t));
+        len += wrlen;
+
+	rc = fwrite(vl + 1, 1, wrlen, f);
+	if(rc)
+		{
+		rc = len;
+		}
+	}
+
+return(rc);
+}
+
+
 /* create / destroy
  */
 struct vlist_t *vlist_create(unsigned int elem_siz)
@@ -143,7 +286,16 @@ if(GLOBALS->vlist_handle)
 		off_t seekpos = (off_t) vl_offs;	/* possible overflow conflicts were already handled in the writer */
 
 		fseeko(GLOBALS->vlist_handle, seekpos, SEEK_SET);
-		rc = fread(&vhdr, sizeof(struct vlist_t), 1, GLOBALS->vlist_handle);
+
+		if(GLOBALS->use_fastload)
+			{
+			rc = vlist_fread_hdr(&vhdr, GLOBALS->vlist_handle);
+			}
+			else
+			{
+			rc = fread(&vhdr, sizeof(struct vlist_t), 1, GLOBALS->vlist_handle);
+			}
+
 		if(!rc)
 			{
 			printf("Error in reading from VList spill file!\n");
@@ -252,7 +404,16 @@ if(vl->offs == vl->siz)
 		long write_cnt;
 
 		fseeko(GLOBALS->vlist_handle, GLOBALS->vlist_bytes_written, SEEK_SET);
-		rc = fwrite(vl, rsiz, 1, GLOBALS->vlist_handle);
+
+		if(GLOBALS->use_fastload)
+			{
+			rc = vlist_fwrite(vl, rsiz, GLOBALS->vlist_handle);
+			}
+			else
+			{
+			rc = fwrite(vl, rsiz, 1, GLOBALS->vlist_handle);
+			}
+
 		if(!rc)
 			{
 			fprintf(stderr, "Error in writing to VList spill file!\n");
@@ -279,7 +440,14 @@ if(vl->offs == vl->siz)
 		*v = v2;
 		vl = *v;
 
-		GLOBALS->vlist_bytes_written += rsiz;
+		if(GLOBALS->use_fastload)
+			{
+			GLOBALS->vlist_bytes_written += rc;
+			}
+			else
+			{
+			GLOBALS->vlist_bytes_written += rsiz;
+			}
 		}
 		else
 		{
@@ -377,7 +545,16 @@ if(GLOBALS->vlist_handle)
 
 	vl = *v;
 	fseeko(GLOBALS->vlist_handle, GLOBALS->vlist_bytes_written, SEEK_SET);
-	rc = fwrite(vl, rsiz, 1, GLOBALS->vlist_handle);
+
+	if(GLOBALS->use_fastload)
+		{
+		rc = vlist_fwrite(vl, rsiz, GLOBALS->vlist_handle);
+		}
+		else
+		{
+		rc = fwrite(vl, rsiz, 1, GLOBALS->vlist_handle);
+		}
+
 	if(!rc)
 		{
 		fprintf(stderr, "Error in writing to VList spill file!\n");
@@ -396,7 +573,15 @@ if(GLOBALS->vlist_handle)
 		}
 
 	*v = (struct vlist_t *)write_cnt;
-	GLOBALS->vlist_bytes_written += rsiz;
+
+	if(GLOBALS->use_fastload)
+		{
+		GLOBALS->vlist_bytes_written += rc;
+		}
+		else
+		{
+		GLOBALS->vlist_bytes_written += rsiz;
+		}
 
 	free_2(vl);
 	}
@@ -626,7 +811,7 @@ attempt2:
 void vlist_packer_finalize(struct vlist_packer_t *p)
 {
 #ifdef WAVE_VLIST_PACKER_STATS
-static unsigned long long pp = 0, upp = 0;
+static guint64 pp = 0, upp = 0;
 #endif
 
 if(p->repcnt)
@@ -780,8 +965,20 @@ free_2(mem - WAVE_ZIVWRAP);
 
 
 /*
- * $Id: vlist.c,v 1.14 2008/12/27 19:55:06 gtkwave Exp $
+ * $Id: vlist.c,v 1.18 2009/10/08 15:32:53 gtkwave Exp $
  * $Log: vlist.c,v $
+ * Revision 1.18  2009/10/08 15:32:53  gtkwave
+ * remove all instances of "long long"
+ *
+ * Revision 1.17  2009/03/05 20:04:52  gtkwave
+ * fix valgrind error in vlist_fwrite()
+ *
+ * Revision 1.16  2009/03/05 16:17:56  gtkwave
+ * added fastload option
+ *
+ * Revision 1.15  2009/03/02 23:31:09  gtkwave
+ * added ability to generate spillfiles in machine independent format
+ *
  * Revision 1.14  2008/12/27 19:55:06  gtkwave
  * remove stray tempfiles under MinGW
  *
