@@ -25,7 +25,11 @@ hadj->upper=GLOBALS->tims.last+2.0;
 
 pageinc=(gfloat)(((gdouble)GLOBALS->wavewidth)*GLOBALS->nspx);
 hadj->page_size=hadj->page_increment=(pageinc>=1.0)?pageinc:1.0;
-hadj->step_increment=(GLOBALS->nspx>=1.0)?GLOBALS->nspx:1.0;
+
+/* hadj->step_increment=(GLOBALS->nspx>=1.0)?GLOBALS->nspx:1.0; */
+
+hadj->step_increment = pageinc / 10.0;
+if(hadj->step_increment < 1.0) hadj->step_increment = 1.0;
 
 if(hadj->page_size >= (hadj->upper-hadj->lower)) hadj->value=hadj->lower;
 if(hadj->value+hadj->page_size>hadj->upper)
@@ -471,8 +475,11 @@ return table;
 }
 
 /*
- * $Id: zoombuttons.c,v 1.4 2007/09/12 19:24:45 gtkwave Exp $
+ * $Id: zoombuttons.c,v 1.5 2008/08/05 20:14:26 gtkwave Exp $
  * $Log: zoombuttons.c,v $
+ * Revision 1.5  2008/08/05 20:14:26  gtkwave
+ * make step_increment equal to 1/10 of the page inc rather than pixel level
+ *
  * Revision 1.4  2007/09/12 19:24:45  gtkwave
  * more ctx_swap_watchdog updates
  *
